from __future__ import annotations
from typing import Any, Union, List, Literal, TypedDict, overload, Optional, Tuple, Dict
from abc import ABCMeta, abstractmethod
from typing import Generator
from typing import Callable
import pandas as pd
from markdown import Markdown
from IPython.core.display import Markdown as Markdown, Math as Math
from fractions import Fraction as NativeFraction
 ##### ./tmp/src/plot_adapter.py #####

class PlotAdapter:
    """
    TableAdapterクラス
    """

    @staticmethod
    def add_column(data_frame: pd.DataFrame, column_name: str | int | float, body: list[str | int | float]) -> None: ...
    @staticmethod
    def display_table(data_frame: pd.DataFrame) -> type['PlotAdapter']: ...
    @staticmethod
    def remove_display_limit(direction: Literal['row', 'column']) -> None: ...
    @staticmethod
    def set_table_index(data_frame: pd.DataFrame, column_name: str | int | float) -> None: ...

class plotRangeClass(TypedDict):


    min: float | int
    max: float | int



class AxBase:
    """
    Parent class representing an axis of a figure.
    """

    def __init__(self, ax: Any) -> None:
        """
        Initialize AxBase with the given axis.
        
        Parameters
        ----------
        ax : Any
            The axis object to be used.
        """
        ...

class FigureBase:
    """
    Parent class representing a figure.
    """

    def __init__(self, row_column: tuple[int, int], size: tuple[int | float, int | float] = (15, 7.5), title: str = '') -> None: ...
    def show(self) -> FigureBase:
        """
        Display the figure.
        
        Returns
        -------
        FigureBase
            The instance of FigureBase.
        """
        ...

 ##### ./tmp/src/__singleton.py #####

class Singleton:


    def __new__(cls, *args, **kwargs): ...
    def __init__(self, user: Literal['human', 'llm'] = 'human') -> None: ...
    @property
    def user(self) -> Literal['human', 'llm']: ...
    def __setattr__(self, key, value) -> None: ...

 ##### ./tmp/src/_ad.py #####

hex_rgb = tuple[int, int, int]
hsl = tuple[float | int, float | int, float | int]
hsla_full = tuple[float | int, float | int, float | int, float | int]
hsla = hsla_full | hsl
plot_color = Literal[
    "aliceblue",
    "antiquewhite",
    "aqua",
    "aquamarine",
    "azure",
    "beige",
    "bisque",
    "black",
    "blanchedalmond",
    "blue",
    "blueviolet",
    "brown",
    "burlywood",
    "cadetblue",
    "chartreuse",
    "chocolate",
    "coral",
    "cornflowerblue",
    "cornsilk",
    "crimson",
    "cyan",
    "darkblue",
    "darkcyan",
    "darkgoldenrod",
    "darkgray",
    "darkgreen",
    "darkgrey",
    "darkkhaki",
    "darkmagenta",
    "darkolivegreen",
    "darkorange",
    "darkorchid",
    "darkred",
    "darksalmon",
    "darkseagreen",
    "darkslateblue",
    "darkslategray",
    "darkslategrey",
    "darkturquoise",
    "darkviolet",
    "deeppink",
    "deepskyblue",
    "dimgray",
    "dimgrey",
    "dodgerblue",
    "firebrick",
    "floralwhite",
    "forestgreen",
    "fuchsia",
    "gainsboro",
    "ghostwhite",
    "gold",
    "goldenrod",
    "gray",
    "green",
    "greenyellow",
    "grey",
    "honeydew",
    "hotpink",
    "indianred",
    "indigo",
    "ivory",
    "khaki",
    "lavender",
    "lavenderblush",
    "lawngreen",
    "lemonchiffon",
    "lightblue",
    "lightcoral",
    "lightcyan",
    "lightgoldenrodyellow",
    "lightgray",
    "lightgreen",
    "lightgrey",
    "lightpink",
    "lightsalmon",
    "lightseagreen",
    "lightskyblue",
    "lightslategray",
    "lightslategrey",
    "lightsteelblue",
    "lightyellow",
    "lime",
    "limegreen",
    "linen",
    "magenta",
    "maroon",
    "mediumaquamarine",
    "mediumblue",
    "mediumorchid",
    "mediumpurple",
    "mediumseagreen",
    "mediumslateblue",
    "mediumspringgreen",
    "mediumturquoise",
    "mediumvioletred",
    "midnightblue",
    "mintcream",
    "mistyrose",
    "moccasin",
    "navajowhite",
    "navy",
    "oldlace",
    "olive",
    "olivedrab",
    "orange",
    "orangered",
    "orchid",
    "palegoldenrod",
    "palegreen",
    "paleturquoise",
    "palevioletred",
    "papayawhip",
    "peachpuff",
    "peru",
    "pink",
    "plum",
    "powderblue",
    "purple",
    "rebeccapurple",
    "red",
    "rosybrown",
    "royalblue",
    "saddlebrown",
    "salmon",
    "sandybrown",
    "seagreen",
    "seashell",
    "sienna",
    "silver",
    "skyblue",
    "slateblue",
    "slategray",
    "slategrey",
    "snow",
    "springgreen",
    "steelblue",
    "tan",
    "teal",
    "thistle",
    "tomato",
    "turquoise",
    "violet",
    "wheat",
    "white",
    "whitesmoke",
    "yellow",
    "yellowgreen",
]
plotRange = tuple[int | float, int | float]
plotRanges = dict[str, plotRange]
plotRange_2d = tuple[plotRange, plotRange]
range_v1 = tuple[int | float, int | float]
range_v2 = tuple[tuple[int | float, int | float], tuple[int | float, int | float]]
variable_symbol = Any
formula_symbol = Any
variables = dict[str, variable_symbol]

class equation(TypedDict):


    formula_left: str
    formula_right: str

operator_symbol = Literal[
    "+",
    "*",
    "**",
    "%",
    "log",
    "/",
    "sin",
    "cos",
    "tan",
    "&",
    "~",
    "|",
    "setInterval",
    "setIntervalUnion",
    "UniversalSet",
    "finite_set",
    "||",
    "floor",
    "sols",
]
#  'sin', 'cos', 'tan', '&', '~', '|', 'setInterval', 'setIntervalUnion', 'finite_set', '||', 'floor','sols']
number_symbol = Literal["oo", "-oo"]
equationSymbol = Literal["="]
conditionSymbol = Literal["True", "False"]
inequationSymbol = Literal["<", "<=", ">", ">="]
unequationSymbol = Literal["!="]
symbolRelationType = Literal[operator_symbol, number_symbol, conditionSymbol, equationSymbol, inequationSymbol, unequationSymbol]
symbolType = Literal[symbolRelationType, "symbol", conditionSymbol]

class vennData(TypedDict):


    label: str
    set: set[int] | set[str]

class plotRange_eachVariable(TypedDict):


    min: int | float
    max: int | float
    symbol: str

sympyClass = Literal[
    "<class 'sympy.core.add.Add'>",
    "<class 'sympy.core.mul.Mul'>",
    "<class 'sympy.core.numbers.Half'>",
    "<class 'sympy.core.numbers.Infinity'>",
    "<class 'sympy.core.numbers.NegativeInfinity'>",
    "<class 'sympy.core.numbers.Rational'>",
    "<class 'sympy.core.power.Pow'>",
    "<class 'sympy.core.relational.Equality'>",
    "<class 'sympy.core.relational.GreaterThan'>",
    "<class 'sympy.core.relational.LessThan'>",
    "<class 'sympy.core.relational.StrictGreaterThan'>",
    "<class 'sympy.core.relational.StrictLessThan'>",
    "<class 'sympy.core.relational.Unequality'>",
    "<class 'sympy.sets.sets.EmptySet'>",
    "<class 'sympy.sets.sets.FiniteSet'>",
    "<class 'sympy.sets.sets.Interval'>",
    "<class 'sympy.sets.sets.Union'>",
    "<class 'sympy.sets.sets.UniversalSet'>",
    "<class 'sympy.logic.boolalg.BooleanFalse'>",
    "<class 'sympy.logic.boolalg.BooleanTrue'>",
    # "<class 'sympy.polys.rootoftools.ComplexRootOf'>",
    "Abs",
    "And",
    "cos",
    "floor",
    "log",
    "Mod",
    "Not",
    "Or",
    "sin",
    "tan",
]
sympyFunction2Operator: dict[sympyClass, symbolRelationType]

class astElement(TypedDict):


    type: Literal['function', 'symbol', 'condition']
    name: symbolType
    text: str
    argumentsLength: int
    arguments: list[astElement]

class variableType(TypedDict):


    real: bool
    integer: bool
    rational: bool
    positive: bool

class variableType_optional(TypedDict, total=False):


    real: Literal[True]
    integer: Literal[True]
    rational: Literal[True]
    positive: Literal[True]

 ##### ./tmp/src/ast.py #####

class Ast:
    """
    Class representing the abstract syntax tree (AST) of a mathematical expression.
    Used for parsing mathematical expressions.
    """

    @staticmethod
    def get_plotable_condition_list(ast: astElement, all_variables: variables, conditions: list[astElement] = []) -> list[astElement]:
        """
        Extracts plotable conditions from the abstract syntax tree (AST).
        
        Parameters
        ----------
        ast : astElement
            The AST to analyze.
        all_variables : variables
            A dictionary containing all variables.
        conditions : List[astElement], optional
            A list of existing conditions. Defaults to an empty list.
        
        Returns
        -------
        List[astElement]
            A list of plotable conditions.
        """
        ...
    def __init__(self, proof: Proof, express: str, assertee_operator: list[symbol_type] = [], variable_types: variable_type_optional | variable_types_optional = {}) -> None:
        """
        Initializes the Ast class.
        
        Parameters
        ----------
        proof : Proof
            Information about the proof.
        express : str
            The string of the mathematical expression to analyze.
        assertee_operator : List[symbol_type], optional
            A list of assertion functions. Defaults to an empty list.
        variable_types : Union[variable_type_optional, variable_types_optional], optional
            Variable type information. Defaults to an empty dictionary.
        """
        ...
    @property
    def ast_prettified_inequation_for_factorize(self) -> astElement:
        """
        Returns the abstract syntax tree (AST) formatted for factorization.
        
        Returns
        -------
        astElement
            The AST formatted for factorization.
        """
        ...
    @property
    def element(self) -> astElement:
        """
        Returns the abstract syntax tree (AST) of the mathematical expression.
        
        Returns
        -------
        astElement
            The AST of the mathematical expression.
        """
        ...
    @property
    def element_not_evaluated(self) -> astElement:
        """
        Returns the unevaluated abstract syntax tree (AST) of the mathematical expression.
        
        Returns
        -------
        astElement
            The unevaluated AST of the mathematical expression.
        """
        ...
    @property
    def evaluated(self) -> astElement:
        """
        Returns the evaluated abstract syntax tree (AST) of the mathematical expression.
        
        Returns
        -------
        astElement
            The evaluated AST of the mathematical expression.
        """
        ...
    @property
    def factors(self) -> list[str]:
        """
        Returns the factors of the mathematical expression.
        
        Returns
        -------
        List[str]
            A list of factors.
        """
        ...
    @property
    def text(self) -> str:
        """
        Returns the abstract syntax tree (AST) as a text.
        
        Returns
        -------
        str
            The AST in text format.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Returns the variables in the mathematical expression.
        
        Returns
        -------
        set[str]
            A set of variables in the expression.
        """
        ...
    def assert_operator(self, assertee_operator: list[symbol_type], should_regressive_search: bool = False) -> Ast:
        """
        Applies the function to the mathematical expression.
        
        Parameters
        ----------
        assertee_operator : List[symbol_type]
            A list of assertion functions.
        should_regressive_search : bool, optional
            Whether to search in reverse order. Default is False.
        
        Returns
        -------
        Ast
            Returns itself.
        """
        ...
    def get_end_leafs(self, ast: astElement | None = None, leaf_type: list[symbol_relation_type] = [], leafs: list[astElement] = []) -> list[astElement]:
        """
        Retrieves the terminal nodes of the abstract syntax tree (AST).
        
        Parameters
        ----------
        ast : astElement, optional
            The AST to analyze. If None, uses ast_prettified_inequation_for_factorize.
        leaf_type : List[symbol_relation_type], optional
            A list of types of terminal nodes to retrieve. Defaults to an empty list.
        leafs : List[astElement], optional
            A list of existing terminal nodes. Defaults to an empty list.
        
        Returns
        -------
        List[astElement]
            A list of terminal nodes.
        """
        ...
    def get_power_term(self, ast: astElement | None = None) -> list[str]:
        """
        Extracts power terms from the specified abstract syntax tree (AST).
        
        Parameters
        ----------
        ast : astElement, optional
            The AST to analyze. If None, uses the element property.
        
        Returns
        -------
        List[str]
            A list of power terms.
        """
        ...

 ##### ./tmp/src/ax.py #####

class Ax(AxBase):
    """
    A class for 2D graph plotting.
    """

    def __init__(self, figure: Figure, ax: Any) -> None:
        """
        Initialize the Ax class.
        
        Parameters
        ----------
        figure : Figure
            The figure object.
        ax : Any
            The axis object.
        """
        ...
    def add_grid(self) -> Ax:
        """
        Add a grid to the plot.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def plot_condition(self, condition: SymbolCondition, axises: list[str] | None = None, color: hsla | None = None) -> Ax:
        """
        Plot a condition on the graph.
        
        Parameters
        ----------
        condition : SymbolCondition
            The condition to plot.
        axises : Union[List[str], None], optional
            The list of axis variables. Defaults to None.
        color : Union[hsla, None], optional
            The color for the plot. Defaults to None.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def plot_line_formula(self, formula: Formula | str | float | int | NativeFraction, variable: str, color: hsla = (220, 100, 50), label: str = '') -> Ax: ...
    def plot_scatter_formula(self, data: list[Position_x] | Positions_list_x, formula: Formula | str | float | int | NativeFraction, variable: str, color: plot_color | hex_rgb = 'black', label: str = '') -> Ax:
        """
        Plot a scatter formula on the graph.
        
        Parameters
        ----------
        data : Union[List[Position_x], Positions_list_x]
            The data points to plot.
        formula : Union[Formula, str, float, int, NativeFraction]
            The formula to plot.
        variable : str
            The variable for the formula.
        color : Union[plot_color, hex_rgb], optional
            The color for the plot. Defaults to "black".
        label : str, optional
            The label for the plot. Defaults to an empty string.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def plot_scatter_points(self, data: list[Position] | Positions_list, color: plot_color | hex_rgb) -> Ax:
        """
        Plot scatter points on the graph.
        
        Parameters
        ----------
        data : Union[List[Position], Positions_list]
            The data points to plot.
        color : Union[plot_color, hex_rgb]
            The color for the points.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def reset_label(self, labels: tuple[str, str]) -> Ax:
        """
        Reset the labels of the plot.
        
        Parameters
        ----------
        labels : Tuple[str, str]
            The new labels for the plot.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def reset_plot_property(self, property: Literal['dot_radius', 'line_width', 'z_order'], value: float | int) -> Ax:
        """
        Reset a property of the plot.
        
        Parameters
        ----------
        property : Literal["dot_radius", "line_width", "z_order"]
            The property to reset.
        value : Union[float, int]
            The new value for the property.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def reset_range(self, _range: plotRange_2d) -> Ax:
        """
        Set the range of the plot.
        
        Note
        ----
        The range should be set before adding areas.
        
        Parameters
        ----------
        _range : plotRange_2d
            The range to set for the plot.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def reset_title(self, title: str) -> Ax:
        """
        Set the title of the plot.
        
        Note
        ----
        The title should be set before adding areas.
        
        Parameters
        ----------
        title : str
            The title for the plot.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...
    def set_legend(self) -> Ax:
        """
        Set the legend for the plot.
        
        Returns
        -------
        Ax
            The Ax instance itself.
        """
        ...

 ##### ./tmp/src/complex_condition.py #####

class ComplexCondition:
    """
    Logical combination of equations, inequalities, and non-equalities.
    """

    def __init__(self, proof: Proof, express: str) -> None:
        """
        Initialize the ComplexCondition class.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        express : str
            The string representation of the expression.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the variables in the expression.
        
        Returns
        -------
        set[str]
            The set of variables.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the expression.
        
        Returns
        -------
        str
            The text representation of the expression.
        """
        ...
    @property
    def logical_tree(self) -> MarkdownContents:
        """
        Get the logical tree of the expression.
        
        Returns
        -------
        MarkdownContents
            The logical tree of the expression.
        """
        ...
    def can_cast(self, type: type_from_term_inequation) -> SymbolicBool:
        """
        Check if the expression can be cast to the specified type.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to check for casting.
        
        Returns
        -------
        SymbolicBool
            The result of the cast check.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of castable types.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    def display(self) -> ComplexCondition:
        """
        Display the expression.
        
        Returns
        -------
        ComplexCondition
            The ComplexCondition instance itself.
        """
        ...
    def display_logical_tree(self) -> ComplexCondition:
        """
        Display the logical tree of the expression.
        
        Returns
        -------
        ComplexCondition
            The ComplexCondition instance itself.
        """
        ...
    def make_figure(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> Figure:
        """
        Create a figure for the expression.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None], optional
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to use alphabetic axis order. Defaults to True.
        title : str, optional
            The title of the figure. Defaults to an empty string.
        
        Returns
        -------
        Figure
            The created figure.
        """
        ...
    def plot(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> ComplexCondition:
        """
        Plot the expression.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None], optional
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to use alphabetic axis order. Defaults to True.
        title : str, optional
            The title of the plot. Defaults to an empty string.
        
        Returns
        -------
        ComplexCondition
            The ComplexCondition instance itself.
        """
        ...
    def __and__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Logical AND operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        symbol_condition
            The result of the logical AND operation.
        """
        ...
    def __eq__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Equality operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        SymbolicBool
            The result of the equality comparison.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format operator.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string.
        """
        ...
    def __ge__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater than or equal operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __gt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater than operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __invert__(self) -> symbol_condition:
        """
        Logical NOT operator.
        
        Returns
        -------
        symbol_condition
            The result of the logical NOT operation.
        """
        ...
    def __le__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less than or equal operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __lshift__(self, other: SymbolCondition) -> MathConditional:
        """
        Left shift operator.
        
        Parameters
        ----------
        other : SymbolCondition
            The operand.
        
        Returns
        -------
        MathConditional
            The result of the left shift operation.
        """
        ...
    def __lt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less than operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __ne__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Not equal operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __or__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Logical OR operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand.
        
        Returns
        -------
        symbol_condition
            The result of the logical OR operation.
        """
        ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool:
        """
        Right shift operator for casting.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted condition.
        """
        ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1:
        """
        Right shift operator for casting.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted condition.
        """
        ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2:
        """
        Right shift operator for casting.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted condition.
        """
        ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...

class ComplexCondition_v1(ComplexCondition):
    """
    Logical combination of equations, inequalities, and non-equalities with a single variable.
    """

    def __init__(self, proof: Proof, express: str) -> None:
        """
        Initialize the ComplexCondition_v1 class.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        express : str
            The string representation of the expression.
        """
        ...
    @property
    def range(self) -> markdown_str:
        """
        Get the range of the condition.
        
        Returns
        -------
        markdown_str
            The range of the condition.
        """
        ...
    def can_get_set_integer(self, set_limit: int = 1000, should_raise_error: bool = False) -> bool:
        """
        Check if the condition can get a set of integers.
        
        Parameters
        ----------
        set_limit : int, optional
            The limit for the set size. Defaults to 1000.
        should_raise_error : bool, optional
            Whether to raise an error if the limit is exceeded. Defaults to False.
        
        Returns
        -------
        bool
            Whether the condition can get a set of integers.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of castable types.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    def display_range(self) -> ComplexCondition_v1:
        """
        Display the range of the condition.
        
        Returns
        -------
        ComplexCondition_v1
            The ComplexCondition_v1 instance itself.
        """
        ...
    def get_set_integer(self, set_limit: int = 1000) -> set[int]:
        """
        Get a set of integers that satisfy the condition.
        
        Parameters
        ----------
        set_limit : int, optional
            The limit for the set size. Defaults to 1000.
        
        Returns
        -------
        set[int]
            The set of integers.
        """
        ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool: ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...
    def __sub__(self, formula: ComplexCondition_v1) -> ComplexCondition_v1 | Equation:
        """
        Subtraction operator.
        
        Parameters
        ----------
        formula : ComplexCondition_v1
            The formula to subtract.
        
        Returns
        -------
        Union[ComplexCondition_v1, Equation]
            The result of the subtraction.
        """
        ...

class ComplexCondition_v2(ComplexCondition):
    """
    Logical combination of equations, inequalities, and non-equalities with two variables.
    """

    def __init__(self, proof: Proof, express: str) -> None:
        """
        Initialize the ComplexCondition_v2 class.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        express : str
            The string representation of the expression.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of castable types.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool: ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...

 ##### ./tmp/src/conditional.py #####

class Conditional(metaclass=ABCMeta):
    """
    Parent class to handle propositions.
    """

    def __init__(self, sufficient_condition: str, necessary_condition: str, sufficient_condition_bool: bool = True, necessary_condition_bool: bool = True) -> None:
        """
        Constructor of the Conditional class.
        
        Parameters
        ----------
        sufficient_condition : str
            The sufficient condition of the proposition.
        necessary_condition : str
            The necessary condition of the proposition.
        sufficient_condition_bool : bool, optional
            Boolean value indicating if the sufficient condition holds (default is True).
        necessary_condition_bool : bool, optional
            Boolean value indicating if the necessary condition holds (default is True).
        """
        ...
    @property
    @abstractmethod
    def converse(self) -> Conditional:
        """
        Abstract property to get the converse proposition.
        
        Returns
        -------
        Conditional
            The converse proposition.
        """
        ...
    @property
    @abstractmethod
    def contrapositive(self) -> Conditional:
        """
        Abstract property to get the contrapositive proposition.
        
        Returns
        -------
        Conditional
            The contrapositive proposition.
        """
        ...
    @property
    @abstractmethod
    def inverse(self) -> Conditional:
        """
        Abstract property to get the inverse proposition.
        
        Returns
        -------
        Conditional
            The inverse proposition.
        """
        ...
    @property
    @abstractmethod
    def opposition(self) -> Conditional:
        """
        Abstract property to get the opposition proposition.
        
        Returns
        -------
        Conditional
            The opposition proposition.
        """
        ...
    @property
    @abstractmethod
    def text(self) -> str:
        """
        Abstract property to get the text of the proposition.
        
        Returns
        -------
        str
            The text of the proposition.
        """
        ...
    @property
    @abstractmethod
    def text_necessary_condition(self) -> str:
        """
        Abstract property to get the text of the necessary condition.
        
        Returns
        -------
        str
            The text of the necessary condition.
        """
        ...
    @property
    @abstractmethod
    def text_sufficient_condition(self) -> str:
        """
        Abstract property to get the text of the sufficient condition.
        
        Returns
        -------
        str
            The text of the sufficient condition.
        """
        ...
    @property
    def text_converse(self) -> str:
        """
        Property to get the text of the converse proposition.
        
        Returns
        -------
        str
            The text of the converse proposition.
        """
        ...
    @property
    def text_inverse(self) -> str:
        """
        Property to get the text of the inverse proposition.
        
        Returns
        -------
        str
            The text of the inverse proposition.
        """
        ...
    @property
    def text_contrapositive(self) -> str:
        """
        Property to get the text of the contrapositive proposition.
        
        Returns
        -------
        str
            The text of the contrapositive proposition.
        """
        ...
    @property
    def text_opposition(self) -> str:
        """
        Property to get the text of the opposition proposition.
        
        Returns
        -------
        str
            The text of the opposition proposition.
        """
        ...
    def add_suffix(self, segment_index: Literal[0, 1], opinion: bool) -> str:
        """
        Adds a suffix based on the segment index and opinion.
        
        Parameters
        ----------
        segment_index : Literal[0, 1]
            Index indicating the segment (0 or 1).
        opinion : bool
            Boolean value indicating the opinion.
        
        Returns
        -------
        str
            The constructed suffix.
        """
        ...
    def analyze_strategy(self) -> Conditional:
        """
        Analyzes the strategy of the proposition and prints various logical transformations.
        
        Returns
        -------
        Conditional
            The current instance of the proposition.
        """
        ...

 ##### ./tmp/src/designed_float.py #####

class Float:
    """
    Class representing a floating-point number, designed for use with the math module.
    
    Parameters
    ----------
    proof : Proof
        An instance of Proof required for various mathematical operations.
    express : float
        The floating-point number represented by this class.
    """

    def __init__(self, proof: Proof, express: float) -> None:
        """
        Initialize the Float object.
        
        Parameters
        ----------
        proof : Proof
            An instance of Proof required for various mathematical operations.
        express : float
            The floating-point number represented by this class.
        """
        ...
    @property
    def ast(self) -> Ast.Ast:
        """
        Get the abstract syntax tree (AST) of the expression.
        
        Returns
        -------
        Ast.Ast
            The AST of the expression.
        """
        ...
    @property
    def degree(self) -> int:
        """
        Get the maximum degree of the expression.
        
        Notes
        -----
        For non-integer polynomials, the result might not be accurate.
        Example: (x**2 + (1/x)**5) -> 5
        
        Returns
        -------
        int
            The maximum degree of the expression.
        """
        ...
    @property
    def is_integer(self) -> bool | None:
        """
        Check if the expression represents an integer.
        
        Returns
        -------
        bool or None
            True if the expression is an integer, None otherwise.
        """
        ...
    @property
    def number(self) -> float:
        """
        Get the floating-point number.
        
        Returns
        -------
        float
            The floating-point number.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the expression.
        
        Returns
        -------
        str
            The text representation of the expression.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the variables involved in the expression.
        
        Returns
        -------
        set of str
            A set of variable names.
        """
        ...
    def can_cast(self, type: type[Integer] | type[Fraction]) -> bool:
        """
        Check if the expression can be cast to a specific type.
        
        Parameters
        ----------
        type : type
            The target type to cast to.
        
        Returns
        -------
        bool
            True if the expression can be cast to the specified type, False otherwise.
        """
        ...
    def display(self) -> Float:
        """
        Display the expression.
        
        Returns
        -------
        Float
            The current instance.
        """
        ...
    def get_coefficients(self, focus_variable: str, should_limit_integer: bool = False) -> list[Float]:
        """
        Get the coefficients of the expression with respect to a focus variable.
        
        Parameters
        ----------
        focus_variable : str
            The variable to focus on.
        should_limit_integer : bool, optional
            Whether to limit the coefficients to integers (default is False).
        
        Returns
        -------
        list of Float
            A list containing the coefficients.
        """
        ...
    def __eq__(self, other: term_) -> SymbolicBool | Equation:
        """
        Evaluate the equality of two expressions.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        SymbolicBool or Equation
            The result of the equality evaluation.
        """
        ...
    def __ne__(self, other: term_) -> SymbolicBool | Unequation:
        """
        Evaluate the inequality of two expressions.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        SymbolicBool or Unequation
            The result of the inequality evaluation.
        """
        ...
    def __lt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if the expression is less than another expression.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        SymbolicBool or Inequation
            The result of the less-than evaluation.
        """
        ...
    def __le__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if the expression is less than or equal to another expression.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        SymbolicBool or Inequation
            The result of the less-than-or-equal evaluation.
        """
        ...
    def __gt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if the expression is greater than another expression.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        SymbolicBool or Inequation
            The result of the greater-than evaluation.
        """
        ...
    def __ge__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if the expression is greater than or equal to another expression.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        SymbolicBool or Inequation
            The result of the greater-than-or-equal evaluation.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the expression according to the specified format.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted expression.
        """
        ...
    @overload
    def __add__(self, formula: float | int | Float | Integer | Fraction) -> Float:
        """
        Add the current expression to another expression.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The expression to add.
        
        Returns
        -------
        Union[Float, Formula]
            The result of the addition.
        """
        ...
    @overload
    def __add__(self, formula: Formula) -> Formula: ...
    @overload
    def __sub__(self, formula: Integer | int | Float | float | Fraction) -> Float:
        """

        """
        ...
    @overload
    def __sub__(self, formula: Formula) -> Formula: ...
    def __neg__(self) -> Float:
        """
        Negate the current expression.
        
        Returns
        -------
        Float
            The negated expression.
        """
        ...
    @overload
    def __mul__(self, formula: Integer | int | Float | float | Fraction) -> Float:
        """
        Multiply the current expression with another expression.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The expression to multiply with.
        
        Returns
        -------
        Union[Float, Formula]
            The result of the multiplication.
        """
        ...
    @overload
    def __mul__(self, formula: Formula) -> Formula: ...
    @overload
    def __truediv__(self, formula: Integer | int | Float | float | Fraction) -> Float:
        """
        Divide the current expression by another expression.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The expression to divide by.
        
        Returns
        -------
        Union[Float, Formula]
            The result of the division.
        """
        ...
    @overload
    def __truediv__(self, formula: Formula) -> Formula: ...
    @overload
    def __mod__(self, formula: Integer | int | Float | float | Fraction) -> Float:
        """
        [%] operator
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction]
            The expression to apply the modulus operator with.
        
        Returns
        -------
        Float
            The result of the modulus operation.
        """
        ...
    @overload
    def __mod__(self, formula: Formula) -> Formula:
        """
        [%] operator
        
        Parameters
        ----------
        formula : Formula
            The expression to apply the modulus operator with.
        
        Returns
        -------
        Formula
            The result of the modulus operation.
        """
        ...
    @overload
    def __floordiv__(self, formula: Integer | int | Float | float | Fraction) -> Integer:
        """
        [//] operator
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction]
            The expression to apply the floor division operator with.
        
        Returns
        -------
        Integer
            The result of the floor division operation.
        """
        ...
    @overload
    def __floordiv__(self, formula: Formula) -> Formula:
        """
        [//] operator
        
        Parameters
        ----------
        formula : Formula
            The expression to apply the floor division operator with.
        
        Returns
        -------
        Formula
            The result of the floor division operation.
        """
        ...
    def __pow__(self, formula: Formula | float | int | Fraction | Integer | Float) -> Formula:
        """
        [**] operator
        
        Parameters
        ----------
        formula : Union[Formula, float, int, Fraction, Integer, Float]
            The expression to apply the power operator with.
        
        Returns
        -------
        Formula
            The result of the power operation.
        """
        ...
    def __radd__(self, formula: float | int) -> Float:
        """
        [+] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the addition operator with.
        
        Returns
        -------
        Float
            The result of the addition operation.
        """
        ...
    def __rsub__(self, formula: float | int) -> Float:
        """
        [-] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the subtraction operator with.
        
        Returns
        -------
        Float
            The result of the subtraction operation.
        """
        ...
    def __rmul__(self, formula: float | int) -> Float:
        """
        [*] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the multiplication operator with.
        
        Returns
        -------
        Float
            The result of the multiplication operation.
        """
        ...
    def __rtruediv__(self, formula: float | int) -> Float:
        """
        [/] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the division operator with.
        
        Returns
        -------
        Float
            The result of the division operation.
        """
        ...
    def __rpow__(self, formula: float | int) -> Formula:
        """
        [**] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the power operator with.
        
        Returns
        -------
        Formula
            The result of the power operation.
        """
        ...
    def __rmod__(self, formula: float | int) -> Float:
        """
        [%] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the modulus operator with.
        
        Returns
        -------
        Float
            The result of the modulus operation.
        """
        ...
    def __rfloordiv__(self, formula: float | int) -> Integer:
        """
        [//] operator
        
        Parameters
        ----------
        formula : Union[float, int]
            The expression to apply the floor division operator with.
        
        Returns
        -------
        Integer
            The result of the floor division operation.
        """
        ...
    @overload
    def __rshift__(self, type: type[Integer]) -> Integer:
        """
        Cast the current expression to a specified type.
        
        Parameters
        ----------
        type : type
            The target type to cast to.
        
        Returns
        -------
        Union[Formula, Integer, Fraction]
            The casted expression.
        """
        ...
    @overload
    def __rshift__(self, type: type[Formula]) -> Formula: ...
    @overload
    def __rshift__(self, type: type[Fraction]) -> Fraction: ...

 ##### ./tmp/src/designed_range.py #####

class Range:
    """
    A class representing the range of real numbers formed by logical combinations of equations, inequalities, and non-equalities.
    
    Attributes
    ----------
    proof : Proof
        Proof object for the range.
    text : str
        The textual representation of the range.
    ast : Ast
        Abstract Syntax Tree (AST) representation of the range.
    variables : set[str]
        Variables involved in the range.
    """

    def __init__(self, proof: Proof, express: str) -> None:
        """
        Initializes the Range class.
        
        Parameters
        ----------
        proof : Proof
            Proof object for the range.
        express : str
            The textual representation of the range.
        """
        ...
    @property
    def ast(self) -> Ast:
        """
        Gets the Abstract Syntax Tree (AST) of the range.
        
        Returns
        -------
        Ast
            AST of the range.
        """
        ...
    @property
    def text(self) -> str:
        """
        Gets the textual representation of the range.
        
        Returns
        -------
        str
            Textual representation of the range.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Gets the variables involved in the range.
        
        Returns
        -------
        set[str]
            Variables involved in the range.
        """
        ...
    def as_set(self, variable: str) -> Set:
        """
        Converts the range to a set for the given variable.
        
        Parameters
        ----------
        variable : str
            Variable for which the range is to be converted to a set.
        
        Returns
        -------
        Set
            The set representation of the range.
        """
        ...
    def can_get_set_integer(self, ast: astElement | None = None, set_limit: int = 1000, should_raise_error: bool = False) -> bool:
        """
        Checks if the integer set can be obtained from the range.
        
        Parameters
        ----------
        ast : Union[astElement, None], optional
            AST element to be used for checking, by default None.
        set_limit : int, optional
            Limit on the size of the set, by default 1000.
        should_raise_error : bool, optional
            Flag to raise error if conditions are not met, by default False.
        
        Returns
        -------
        bool
            True if the integer set can be obtained, False otherwise.
        """
        ...
    def display(self) -> Range:
        """
        Displays the range.
        
        Returns
        -------
        Range
            The range itself.
        """
        ...
    def get_set_integer(self, ast: astElement | None = None, set_limit: int = 1000) -> set[int]:
        """
        Gets the set of integers from the range.
        
        Parameters
        ----------
        ast : Union[astElement, None], optional
            AST element to be used for getting the set, by default None.
        set_limit : int, optional
            Limit on the size of the set, by default 1000.
        
        Returns
        -------
        set[int]
            The set of integers from the range.
        """
        ...
    def __and__(self, formula: Range) -> Set | Range:
        """
        Logical AND operation for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to perform the AND operation with.
        
        Returns
        -------
        Union[Set, Range]
            The result of the AND operation.
        """
        ...
    def __eq__(self, formula: Range) -> bool:
        """
        Equality comparison for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to compare with.
        
        Returns
        -------
        bool
            True if the ranges are equal, False otherwise.
        """
        ...
    def __format__(self, __format_spec: str) -> markdown_str:
        """
        Formats the range for display.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        markdown_str
            The formatted range as markdown string.
        """
        ...
    def __ge__(self, formula: Range) -> bool:
        """
        Greater than or equal to comparison for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to compare with.
        
        Returns
        -------
        bool
            True if the range is greater than or equal to the compared range, False otherwise.
        """
        ...
    def __gt__(self, formula: Range) -> bool:
        """
        Greater than comparison for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to compare with.
        
        Returns
        -------
        bool
            True if the range is greater than the compared range, False otherwise.
        """
        ...
    def __le__(self, formula: Range) -> bool:
        """
        Less than or equal to comparison for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to compare with.
        
        Returns
        -------
        bool
            True if the range is less than or equal to the compared range, False otherwise.
        """
        ...
    def __lt__(self, formula: Range) -> bool:
        """
        Less than comparison for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to compare with.
        
        Returns
        -------
        bool
            True if the range is less than the compared range, False otherwise.
        """
        ...
    def __ne__(self, formula: Range) -> bool:
        """
        Non-equality comparison for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to compare with.
        
        Returns
        -------
        bool
            True if the ranges are not equal, False otherwise.
        """
        ...
    def __or__(self, formula: Range) -> Set | Range:
        """
        Logical OR operation for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to perform the OR operation with.
        
        Returns
        -------
        Union[Set, Range]
            The result of the OR operation.
        """
        ...
    def __sub__(self, formula: Range) -> Set | Range:
        """
        Subtraction operation for ranges.
        
        Parameters
        ----------
        formula : Range
            The range to perform the subtraction operation with.
        
        Returns
        -------
        Union[Set, Range]
            The result of the subtraction operation.
        """
        ...

 ##### ./tmp/src/designed_set.py #####

class Set:
    """
    Represents a set in the designed math module.
    Elements are primarily integers.
    
    Parameters
    ----------
    proof : Proof
        The proof object.
    express : Union[str, set[str], set[int], set[float]], optional
        The initial expression or set of elements. Default is an empty set.
    
    Attributes
    ----------
    text : str
        The string representation of the set.
    native_set : set[int]
        The set of elements converted to integers.
    """

    def __init__(self, proof: Proof, express: express_str | express_str_set | express_int_set | express_float_set = set()) -> None: ...
    @property
    def native_set(self) -> set[int]:
        """
        Returns the set of elements converted to integers.
        
        Returns
        -------
        set[int]
            The set of elements converted to integers.
        """
        ...
    @property
    def text(self) -> str:
        """
        Returns the string representation of the set.
        
        Returns
        -------
        str
            The string representation of the set.
        """
        ...
    def display(self) -> Set:
        """
        Displays the set using the SymbolAdapter2.
        
        Returns
        -------
        Set
            The current set object.
        """
        ...
express_str = str
express_str_set = set[str]
express_int_set = set[int]
express_float_set = set[float]

 ##### ./tmp/src/diophantine_equation_utils.py #####

class DiophantineEquationUtils:
    """
    Utility class for solving Diophantine equations.
    Used for equations of different dimensions (d) and variables (v).
    """

    @staticmethod
    def get_solution_range_of_diophantine_equation(equation: Equation, proof: Proof, variable_size_order: list[str], is_order_strict: bool = False, section_title: str = '不定方程式の解の範囲', section_id: str = 'get_solution_range_of_diophantine_equation') -> list[Inequation]:
        """
        Get the range of solutions for a Diophantine equation.
        
        Parameters
        ----------
        equation : Equation
            The Diophantine equation to solve.
        proof : Proof
            The proof object.
        variable_size_order : List[str]
            The order of variables by size.
        is_order_strict : bool, optional
            Whether the size order is strict, by default False
        section_title : str, optional
            The title of the proof section, by default "Range of Solutions of Diophantine Equation"
        section_id : str, optional
            The ID of the proof section, by default "get_solution_range_of_diophantine_equation"
        
        Returns
        -------
        List[Inequation]
            A list of inequalities representing the solution range.
        """
        ...
    @staticmethod
    def solve_diophantine_equation_d1_v2(equation: Equation, proof: Proof, parameter_symbol: str = 'k_', search_range: tuple[int, int] = (-5, 5), section_title: str = '１次２変数の不定方程式の解', section_id: str = 'solve_diophantine_equation_d1_v2') -> VectorEquation: ...
    @staticmethod
    def solve_diophantine_equation_d1_v2_disassembly_type(equation: Equation, proof: Proof, section_title: str = '１次２変数の不定方程式(分解型)の解', section_id: str = 'solve_diophantine_equation_d1_v2_disassembly_type') -> VectorSolutions: ...
    @staticmethod
    def solve_diophantine_equation_d2_v2_disassembly_type(equation: Equation, proof: Proof, is_natural_number: bool = False, section_title: str = '２次２変数の不定方程式(分解型)の解', section_id: str = 'solve_diophantine_equation_d2_v2_disassembly_type') -> VectorSolutions: ...
    @staticmethod
    def solve_diophantine_equation_add_and_subtract_products(proof: Proof, equation: add_and_subtract_products_equation, is_natural_number: bool = False, section_title: str = '２乗差の不定方程式の解', section_id: str = 'solve_diophantine_equation_add_and_subtract_products') -> VectorSolutions:
        """
        Solves a Diophantine equation of the sum and difference of products.
        
        Parameters
        ----------
        proof : Proof
            The proof object used to verify the solution.
        equation : add_and_subtract_products_equation
            The equation to be solved.
        is_natural_number : bool, optional
            Whether the solution should be restricted to natural numbers, by default False.
        section_title : str, optional
            Title for the section in the proof, by default "Solution of the Diophantine equation of the sum and difference of products".
        section_id : str, optional
            ID for the section in the proof, by default "solve_diophantine_equation_add_and_subtract_products".
        
        Returns
        -------
        VectorSolutions
            The solutions as vector equations.
        """
        ...
    @staticmethod
    def solve_diophantine_equation_symmetric(equation: Equation, proof: Proof, variable_size_order: list[str] = [], is_order_strict: bool = False, section_title: str = 'Solution of Symmetric Diophantine Equation', section_id: str = 'solve_diophantine_equation_symmetric') -> VectorSolutions | None:
        """
        Solve symmetric Diophantine equations.
        
        Note
        ----
        May need extensions for flexible handling of variable size relations. Current implementation has limited scope.
        Solutions are limited to natural numbers.
        
        Parameters
        ----------
        equation : Equation
            The Diophantine equation to solve. The right-hand side must be an integer.
        proof : Proof
            The proof object.
        variable_size_order : List[str], optional
            The order of variables by size, by default []
        is_order_strict : bool, optional
            Whether the size order is strict, by default False
        section_title : str, optional
            The title of the proof section, by default "Solution of Symmetric Diophantine Equation"
        section_id : str, optional
            The ID of the proof section, by default "solve_diophantine_equation_symmetric"
        
        Returns
        -------
        VectorSolutions or None
            The set of solutions of the Diophantine equation, or None if no solution exists.
        """
        ...
    @staticmethod
    def solve_equation_of_rapidly_increase_each_sides_difference(equation: Equation, proof: Proof, scan_range: tuple[int, int] = (0, 10), section_title: str = '急速に差が開く等式の解法', section_id: str = 'solve_equation_of_rapidly_increase_each_sides_difference') -> Solutions: ...

 ##### ./tmp/src/equation.py #####

class Equation:
    """
    Represents a general mathematical equation.
    
    Attributes
    ----------
    proof : Proof
        The proof object associated with the equation.
    formulas : Tuple[Formula, Formula]
        The left and right formulas of the equation.
    variables : set[str]
        The set of variables used in the equation.
    
    Parameters
    ----------
    proof : Proof
        The proof object associated with the equation.
    equation : Union[str, term_pair]
        The equation represented as a string or a pair of terms.
    """

    def __init__(self, proof: Proof, equation: str | term_pair) -> None:
        """
        Initialize an Equation object.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the equation.
        equation : Union[str, term_pair]
            The equation represented as a string or a pair of terms.
        """
        ...
    @property
    def degree(self) -> int:
        """
        Return the maximum degree of the equation.
        
        Notes
        -----
        This function does not return the correct result for non-integer polynomials.
        Example: (x**2 + (1/x)**5) -> 5
        
        Returns
        -------
        int
            The maximum degree of the equation.
        """
        ...
    @property
    def evaluated(self) -> Equation | SymbolicBool:
        """
        Evaluate the equation.
        
        Returns
        -------
        Union[Equation, SymbolicBool]
            The evaluated equation or symbolic boolean.
        """
        ...
    @property
    def formulas(self) -> tuple[Formula, Formula]:
        """
        Return the formulas of the equation.
        
        Returns
        -------
        Tuple[Formula, Formula]
            The left and right formulas of the equation.
        """
        ...
    @property
    def text(self) -> str:
        """
        Return the equation as a string.
        
        Returns
        -------
        str
            The equation as a string.
        """
        ...
    @property
    def text_for_display(self) -> str:
        """
        Return the equation text for display.
        
        Returns
        -------
        str
            The equation text for display.
        """
        ...
    @property
    def text_for_input(self) -> str:
        """
        Return the equation text for input.
        
        Returns
        -------
        str
            The equation text for input.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Return the set of variables used in the equation.
        
        Returns
        -------
        set[str]
            The set of variables used in the equation.
        """
        ...
    def can_cast(self, type: type_from_term_inequation) -> SymbolicBool:
        """
        Check if the equation can be cast to a specific type.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        SymbolicBool
            The result of the cast check.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Return the types the equation can be cast to.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of types the equation can be cast to.
        """
        ...
    def display(self, is_raw: bool = True) -> Equation:
        """
        Display the equation.
        
        Parameters
        ----------
        is_raw : bool, optional
            Whether to display the raw equation, by default True.
        
        Returns
        -------
        Equation
            The displayed equation.
        """
        ...
    def factorize(self) -> Equation:
        """
        Factorize the equation.
        
        Returns
        -------
        Equation
            The factorized equation.
        """
        ...
    def get_particular_solution_d1_v2(self, search_range: tuple[int, int]) -> dict_int | None:
        """
        Get a particular solution of the equation.
        
        Parameters
        ----------
        search_range : Tuple[int, int]
            The search range for the solution.
        
        Returns
        -------
        Union[dict_int, None]
            The particular solution of the equation.
        """
        ...
    def get_solution_range_of_diophantine_equation(self, variable_size_order: list[str], is_order_strict: bool = False, section_title: str = '不定方程式の解の範囲', section_id: str = 'get_solution_range_of_diophantine_equation') -> list[Inequation]:
        """
        Get the solution range of a diophantine equation.
        
        Parameters
        ----------
        variable_size_order : List[str]
            The order of the variables.
        is_order_strict : bool, optional
            Whether the order is strict, by default False.
        section_title : str, optional
            The title of the section, by default "不定方程式の解の範囲".
        section_id : str, optional
            The ID of the section, by default "get_solution_range_of_diophantine_equation".
        
        Returns
        -------
        List[Inequation]
            The solution range of the diophantine equation.
        """
        ...
    def is_definition(self) -> bool:
        """
        Check if the equation is a definition.
        
        Returns
        -------
        bool
            True if the equation is a definition, False otherwise.
        """
        ...
    def is_identity(self) -> bool:
        """
        Check if the equation is an identity.
        
        Returns
        -------
        bool
            True if the equation is an identity, False otherwise.
        """
        ...
    def make_figure(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> Figure:
        """
        Create a figure for the equation.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to order the axes alphabetically, by default True.
        title : str, optional
            The title of the figure, by default "".
        
        Returns
        -------
        Figure
            The created figure.
        """
        ...
    def plot(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> SymbolCondition:
        """
        Plot the equation.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to order the axes alphabetically, by default True.
        title : str, optional
            The title of the figure, by default "".
        
        Returns
        -------
        SymbolCondition
            The plotted symbol condition.
        """
        ...
    def solve(self, focus_variable: str | Formula) -> FormulaVector:
        """
        Solve the equation for a specific variable.
        
        Parameters
        ----------
        focus_variable : Union[str, Formula]
            The variable to solve for.
        
        Returns
        -------
        FormulaVector
            The solution of the equation.
        """
        ...
    def solve_diophantine_equation_d1_v2(self, parameter_symbol: str = 'k_', search_range: tuple[int, int] = (-5, 5), section_title: str = '１次２変数の不定方程式の解', section_id: str = 'solve_diophantine_equation_d1_v2') -> VectorEquation: ...
    def solve_diophantine_equation_d1_v2_disassembly_type(self, section_title: str = '１次２変数の不定方程式(分解型)の解', section_id: str = 'solve_diophantine_equation_d1_v2_disassembly_type') -> VectorSolutions: ...
    def solve_diophantine_equation_d2_v2_disassembly_type(self, is_natural_number: bool = False, section_title: str = '２次２変数の不定方程式(分解型)の解', section_id: str = 'solve_diophantine_equation_d2_v2_disassembly_type') -> VectorSolutions: ...
    def solve_diophantine_equation_add_and_subtract_products(self, equation: add_and_subtract_products_equation, is_natural_number: bool = False, section_title: str = '２乗差の不定方程式の解', section_id: str = 'solve_diophantine_equation_add_and_subtract_products') -> VectorSolutions:
        """
        Solve a diophantine equation of the form ax^2 - bx^2 = c.
        
        Parameters
        ----------
        equation : add_and_subtract_products_equation
            The equation to solve.
        is_natural_number : bool, optional
            Whether the solution should be a natural number, by default False.
        section_title : str, optional
            The title of the section, by default "２乗差の不定方程式の解".
        section_id : str, optional
            The ID of the section, by default "solve_diophantine_equation_add_and_subtract_products".
        
        Returns
        -------
        VectorSolutions
            The solution of the diophantine equation.
        """
        ...
    def solve_diophantine_equation_symmetric(self, variable_size_order: list[str] = [], is_order_strict: bool = False, section_title: str = '対称式の不定方程式の解', section_id: str = 'solve_diophantine_equation_symmetric') -> VectorSolutions | None:
        """
        Solve a symmetric diophantine equation.
        
        Parameters
        ----------
        variable_size_order : List[str], optional
            The order of the variables, by default [].
        is_order_strict : bool, optional
            Whether the order is strict, by default False.
        section_title : str, optional
            The title of the section, by default "対称式の不定方程式の解".
        section_id : str, optional
            The ID of the section, by default "solve_diophantine_equation_symmetric".
        
        Returns
        -------
        Union[VectorSolutions, None]
            The solution of the diophantine equation.
        """
        ...
    def solve_equation_of_rapidly_increase_each_sides_difference(self, scan_range: tuple[int, int] = (0, 10), section_title: str = '急速に差が開く等式の解法', section_id: str = 'solve_equation_of_rapidly_increase_each_sides_difference') -> Solutions: ...
    def substitute(self, conditions: dict_float | dict_int | dict_term | Equation | Equations, side: literal_direction | None = None) -> Equation:
        """
        Substitute values into the equation.
        
        Parameters
        ----------
        conditions : Union[dict_float, dict_int, dict_term, Equation, Equations]
            The conditions for substitution.
        side : Union[literal_direction, None], optional
            The side to substitute, by default None.
        
        Returns
        -------
        Equation
            The equation with substituted values.
        """
        ...
    def __add__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Add another equation or term to this equation.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to add.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __and__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Perform a logical AND operation with another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to AND with.
        
        Returns
        -------
        symbol_condition
            The result of the logical AND.
        """
        ...
    def __eq__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Check if the equation is equal to another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the equality check.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the equation as a string.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string.
        """
        ...
    def __ge__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Check if the equation is greater than or equal to another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the greater-than-or-equal-to check.
        """
        ...
    def __gt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Check if the equation is greater than another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the greater-than check.
        """
        ...
    def __invert__(self) -> symbol_condition:
        """
        Invert the equation.
        
        Returns
        -------
        symbol_condition
            The inverted equation.
        """
        ...
    def __le__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Check if the equation is less than or equal to another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the less-than-or-equal-to check.
        """
        ...
    def __lt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Check if the equation is less than another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the less-than check.
        """
        ...
    def __lshift__(self, other: SymbolCondition) -> MathConditional:
        """
        Perform a left shift operation.
        
        Parameters
        ----------
        other : SymbolCondition
            The other condition to shift.
        
        Returns
        -------
        MathConditional
            The result of the left shift.
        """
        ...
    def __mul__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Multiply this equation by another equation or term.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to multiply.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __ne__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Check if the equation is not equal to another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the inequality check.
        """
        ...
    def __neg__(self) -> Fraction:
        """
        Negate the equation.
        
        Returns
        -------
        Fraction
            The negated equation.
        """
        ...
    def __or__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Perform a logical OR operation with another condition.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other condition to OR with.
        
        Returns
        -------
        symbol_condition
            The result of the logical OR.
        """
        ...
    def __pow__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Raise this equation to the power of another equation or term.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to raise to the power of.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __sub__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Subtract another equation or term from this equation.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to subtract.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __truediv__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Divide this equation by another equation or term.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to divide by.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __radd__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Add this equation to another equation or term.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to add.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __rmul__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Multiply another equation or term by this equation.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to multiply.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __rpow__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Raise another equation or term to the power of this equation.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to raise to the power of.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool:
        """
        Shift the equation to the right.
        
        Parameters
        ----------
        type : Union[type_from_term_inequation, ExplainEquation, DefineEquation]
            The type to shift to.
        
        Returns
        -------
        Union[symbol_condition, ExplainEquation, DefineEquation]
            The resulting condition or equation.
        """
        ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[DefineEquation]) -> DefineEquation: ...
    @overload
    def __rshift__(self, type: type[ExplainEquation]) -> ExplainEquation: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...
    def __rsub__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Subtract this equation from another equation or term.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to subtract.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...
    def __rtruediv__(self, equation_or_term: Equation | Term | int | float | NativeFraction) -> Equation:
        """
        Divide another equation or term by this equation.
        
        Parameters
        ----------
        equation_or_term : Union[Equation, Term, int, float, NativeFraction]
            The equation or term to divide by.
        
        Returns
        -------
        Equation
            The resulting equation.
        """
        ...

class Equation_2d(Equation):
    """
    Represents a 2-dimensional equation.
    
    Parameters
    ----------
    proof : Proof
        The proof object associated with the equation.
    equation : Union[str, term_pair]
        The equation represented as a string or a pair of terms.
    main_variable : str, optional
        The main variable of the equation, by default "".
    """

    def __init__(self, proof: Proof, equation: str | term_pair, main_variable: str = '') -> None:
        """
        Initialize an Equation_2d object.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the equation.
        equation : Union[str, term_pair]
            The equation represented as a string or a pair of terms.
        main_variable : str, optional
            The main variable of the equation, by default "".
        """
        ...
    @property
    def a(self) -> Formula:
        """
        Return the coefficient a.
        
        Returns
        -------
        Formula
            The coefficient a.
        """
        ...
    @property
    def b(self) -> Formula:
        """
        Return the coefficient b.
        
        Returns
        -------
        Formula
            The coefficient b.
        """
        ...
    @property
    def c(self) -> Formula:
        """
        Return the coefficient c.
        
        Returns
        -------
        Formula
            The coefficient c.
        """
        ...
    @property
    def discriminant(self) -> Formula:
        """
        Return the discriminant of the equation.
        
        Returns
        -------
        Formula
            The discriminant of the equation.
        """
        ...
    @property
    def vietas_formulas_addition(self) -> Formula:
        """
        Return the addition from Vieta's formulas.
        
        Returns
        -------
        Formula
            The addition from Vieta's formulas.
        """
        ...
    @property
    def vietas_formulas_product(self) -> Formula:
        """
        Return the product from Vieta's formulas.
        
        Returns
        -------
        Formula
            The product from Vieta's formulas.
        """
        ...

class ExplainEquation(Equation):
    """
    Represents an equation where the left side is a single variable.
    
    Parameters
    ----------
    proof : Proof
        The proof object associated with the equation.
    equation : Union[str, formula_term_pair]
        The equation represented as a string or a pair of terms.
    """

    def __init__(self, proof: Proof, equation: str | formula_term_pair) -> None:
        """
        Initialize an ExplainEquation object.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the equation.
        equation : Union[str, formula_term_pair]
            The equation represented as a string or a pair of terms.
        """
        ...

class DefineEquation(ExplainEquation):
    """
    Represents a definition equation.
    
    Parameters
    ----------
    proof : Proof
        The proof object associated with the equation.
    equation : Union[str, formula_term_pair]
        The equation represented as a string or a pair of terms.
    """

    def __init__(self, proof: Proof, equation: str | formula_term_pair) -> None:
        """
        Initialize a DefineEquation object.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the equation.
        equation : Union[str, formula_term_pair]
            The equation represented as a string or a pair of terms.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the definition equation as a string.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string.
        """
        ...

term_pair = Tuple[term, term]
formula_term_pair = Tuple[Formula, term]
dict_float = dict[str, float]
dict_int = dict[str, int]
dict_term = Dict[str, Term]
literal_direction = Literal["left", "right"]

 ##### ./tmp/src/equation_utils.py #####

default_condition: condition

class EquationUtils:
    """
    Utility class for handling equations.
    """

    @staticmethod
    def adjust_function(proof: Proof, equation: Equation, adjust_function_symbol: Literal['+', '-', '*', '/', '**'], equation_or_term: Equation | Term | float | int | NativeFraction, is_operate_from_right: bool = True) -> Equation:
        """
        Adjusts the given equation by applying an arithmetic operation
        with another equation, term, or number.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the equation.
        equation : Equation
            The equation to be adjusted.
        adjust_function_symbol : {'+', '-', '*', '/', '**'}
            The arithmetic operation to be applied.
        equation_or_term : Union[Equation, Term, float, int, NativeFraction]
            The equation, term, or number to adjust with.
        is_operate_from_right : bool, optional
            Indicates whether to apply the operation from the right side.
            Default is True.
        
        Returns
        -------
        Equation
            The adjusted equation.
        """
        ...

 ##### ./tmp/src/equations.py #####

class Equations:
    """
    Class for handling systems of simultaneous equations.
    
    Attributes
    ----------
    text : str
        Representation of the equations as text.
    variables : set of str
        Set of variables in the equations.
    equations : list of Equation
        List of equations in the system.
    
    Methods
    -------
    add_equation(equations: List[Equation]) -> Equations
        Adds multiple equations to the system.
    append(equation: Equation) -> Equations
        Appends a single equation to the system.
    solve(focus_terms: set[str] = set()) -> Union[VectorEquation, None]
        Solves the system of equations.
    display() -> Equations
        Displays the equations.
    reduce_variable(target_variable: str = "", define_equation: Union[Equation, None] = None) -> Equations
        Reduces the equations by a target variable or a given equation.
    """

    def __init__(self, proof: Proof, equations: express_list | express_tuple) -> None:
        """
        Parameters
        ----------
        proof : Proof
            Proof object associated with the equations.
        equations : Union[List[Equation], Tuple[Vector, Vector]]
            Equations to be included in the system.
        """
        ...
    @property
    def equations(self) -> list[Equation]:
        """
        Returns
        -------
        list of Equation
            List of equations in the system.
        """
        ...
    @property
    def text(self) -> str:
        """
        Returns
        -------
        str
            Text representation of the equations.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Returns
        -------
        set of str
            Set of variables in the equations.
        """
        ...
    def add_equation(self, equations: list[Equation]) -> Equations:
        """
        Adds multiple equations to the system.
        
        Parameters
        ----------
        equations : list of Equation
            Equations to be added.
        
        Returns
        -------
        Equations
            Updated instance of the system of equations.
        """
        ...
    def append(self, equation: Equation) -> Equations:
        """
        Appends a single equation to the system.
        
        Parameters
        ----------
        equation : Equation
            Equation to be appended.
        
        Returns
        -------
        Equations
            Updated instance of the system of equations.
        """
        ...
    def display(self) -> Equations:
        """
        Displays the equations.
        
        Returns
        -------
        Equations
            The instance itself.
        """
        ...
    def reduce_variable(self, target_variable: str = '', define_equation: Equation | None = None) -> Equations:
        """
        Reduces the equations by a target variable or a given equation.
        
        Parameters
        ----------
        target_variable : str, optional
            Variable to reduce by (default is an empty string).
        define_equation : Union[Equation, None], optional
            Equation to use for reduction (default is None).
        
        Returns
        -------
        Equations
            Reduced system of equations.
        """
        ...
    def solve(self, focus_terms: set[str] = set()) -> VectorEquation | None: ...
    def __getitem__(self, index: int) -> Equation:
        """
        Gets an equation by index.
        
        Parameters
        ----------
        index : int
            Index of the equation to retrieve.
        
        Returns
        -------
        Equation
            Equation at the specified index.
        """
        ...
    def __iter__(self) -> Generator[Equation, None, None]:
        """
        Iterates over the equations in the system.
        
        Yields
        ------
        Generator[Equation, None, None]
            Generator of equations.
        """
        ...
    def __len__(self) -> int:
        """
        Returns the number of equations in the system.
        
        Returns
        -------
        int
            Number of equations.
        """
        ...

class Solutions(Equations):
    """
    Class for handling solutions of simultaneous equations, with each variable solved.
    
    Methods
    -------
    sort(should_reverse: bool = False) -> Solutions
        Sorts the solutions.
    display() -> Solutions
        Displays the solutions.
    """

    def __init__(self, proof: Proof, equations: list[Equation] | tuple[Vector, Vector]) -> None:
        """
        Parameters
        ----------
        proof : Proof
            Proof object associated with the solutions.
        equations : Union[List[Equation], Tuple[Vector, Vector]]
            Equations to be included in the solutions.
        """
        ...
    def display(self) -> Solutions:
        """
        Displays the solutions.
        
        Returns
        -------
        Solutions
            The instance itself.
        """
        ...
    def sort(self, should_reverse: bool = False) -> Solutions:
        """
        Sorts the solutions.
        
        Parameters
        ----------
        should_reverse : bool, optional
            If True, sort in reverse order (default is False).
        
        Returns
        -------
        Solutions
            Sorted solutions.
        """
        ...
    def __add__(self, other: Solutions) -> Solutions:
        """
        Adds another set of solutions to this one.
        
        Parameters
        ----------
        other : Solutions
            Another set of solutions.
        
        Returns
        -------
        Solutions
            Combined solutions.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Formats the solutions for display.
        
        Parameters
        ----------
        __format_spec : str
            Format specification.
        
        Returns
        -------
        str
            Formatted solutions.
        """
        ...

class VectorEquation(Equations):
    """
    Class for handling vector equations.
    
    Attributes
    ----------
    left_side_vector : Vector
        Left side vector of the equations.
    right_side_vector : Vector
        Right side vector of the equations.
    
    Methods
    -------
    add_equation(equations: List[Equation]) -> VectorEquation
        Adds multiple equations to the vector equation.
    append(equation: Equation) -> VectorEquation
        Appends a single equation to the vector equation.
    sort(should_reverse: bool = False) -> VectorEquation
        Sorts the equations in the vector equation.
    display() -> VectorEquation
        Displays the vector equation.
    """

    def __init__(self, proof: Proof, equations: list[Equation] | tuple[Vector, Vector]) -> None:
        """
        Parameters
        ----------
        proof : Proof
            Proof object associated with the vector equation.
        equations : Union[List[Equation], Tuple[Vector, Vector]]
            Equations to be included in the vector equation.
        """
        ...
    @property
    def left_side_vector(self) -> Vector:
        """
        Returns
        -------
        Vector
            Left side vector of the equations.
        """
        ...
    @property
    def right_side_vector(self) -> Vector:
        """
        Returns
        -------
        Vector
            Right side vector of the equations.
        """
        ...
    def add_equation(self, equations: list[Equation]) -> VectorEquation:
        """
        Adds multiple equations to the vector equation.
        
        Parameters
        ----------
        equations : list of Equation
            Equations to be added.
        
        Returns
        -------
        VectorEquation
            Updated vector equation.
        """
        ...
    def append(self, equation: Equation) -> VectorEquation:
        """
        Appends a single equation to the vector equation.
        
        Parameters
        ----------
        equation : Equation
            Equation to be appended.
        
        Returns
        -------
        VectorEquation
            Updated vector equation.
        """
        ...
    def display(self) -> VectorEquation:
        """
        Displays the vector equation.
        
        Returns
        -------
        VectorEquation
            The instance itself.
        """
        ...
    def sort(self, should_reverse: bool = False) -> VectorEquation:
        """
        Sorts the equations in the vector equation.
        
        Parameters
        ----------
        should_reverse : bool, optional
            If True, sort in reverse order (default is False).
        
        Returns
        -------
        VectorEquation
            Sorted vector equation.
        """
        ...
    def __eq__(self, other: VectorEquation) -> bool:
        """
        Checks if two vector equations are equal.
        
        Parameters
        ----------
        other : VectorEquation
            Other vector equation to compare.
        
        Returns
        -------
        bool
            True if equal, False otherwise.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Formats the vector equation for display.
        
        Parameters
        ----------
        __format_spec : str
            Format specification.
        
        Returns
        -------
        str
            Formatted vector equation.
        """
        ...

express_list = List[Equation]
express_tuple = Tuple[Vector, Vector]

 ##### ./tmp/src/figure.py #####

class Figure(FigureBase):
    """
    Represents a figure containing multiple subplots.
    
    Parameters
    ----------
    proof : Proof
        The proof associated with the figure.
    row_column : Tuple[int, int]
        The number of rows and columns in the figure.
    unit_size : Tuple[Union[int, float], Union[int, float]], optional
        The size of each unit in the figure, by default (5, 5).
    title : str, optional
        The title of the figure, by default "".
    
    Attributes
    ----------
    proof : Proof
        The proof associated with the figure.
    axes : List[List[Ax]]
        The list of axes in the figure.
    """

    def __init__(self, proof: Proof, row_column: tuple[int, int], unit_size: tuple[int | float, int | float] = (5, 5), title: str = '') -> None: ...
    @property
    def axes(self) -> list[list[Ax]]:
        """
        Returns the list of axes in the figure.
        
        Returns
        -------
        List[List[Ax]]
            The list of axes in the figure.
        """
        ...
    @property
    def proof(self) -> Proof:
        """
        Returns the proof associated with the figure.
        
        Returns
        -------
        Proof
            The proof associated with the figure.
        """
        ...
    def add_subplot(self, row_column: tuple[int, int]) -> Figure:
        """
        Adds a subplot to the figure at the specified row and column.
        
        Parameters
        ----------
        row_column : Tuple[int, int]
            The position of the subplot in terms of row and column.
        
        Returns
        -------
        Figure
            The updated figure object.
        """
        ...
    def display(self) -> Figure:
        """
        Displays the figure.
        
        Returns
        -------
        Figure
            The displayed figure object.
        """
        ...

 ##### ./tmp/src/figure_reservation.py #####

class FigureReservation:
    """
    Figure Reservation Class.
    This class is used to defer the rendering of figures defined within the instance
    to prevent the output sequence from being disrupted.
    
    Parameters
    ----------
    express : Union[SymbolCondition, Formula]
        The expression to be plotted, which can be a symbol condition or a formula.
    plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None], optional
        The range for plotting, can be one of several plot range types or None.
    alphabetic_axis_order : bool, optional
        If True, use alphabetic order for axis labeling (default is True).
    title : str, optional
        The title of the plot (default is an empty string).
    """

    def __init__(self, express: SymbolCondition | Formula, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> None: ...
    def display(self) -> FigureReservation:
        """
        Display the figure.
        
        This method plots the figure based on the given expression and plot ranges.
        
        Returns
        -------
        FigureReservation
            The instance of the FigureReservation class.
        """
        ...

 ##### ./tmp/src/formula.py #####

class Formula:
    """
    A class to represent a formula composed of numbers, constants, variables, and operators.
    """

    def __init__(self, proof: Proof, text: str | float | int, variable_types: variable_type_optional | variable_types_optional = {}) -> None:
        """
        Initialize a formula.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with this formula.
        text : Union[str, float, int]
            The text representation of the formula.
        variable_types : Union[variable_type_optional, variable_types_optional], optional
            A dictionary of variable types, by default {}.
        """
        ...
    @property
    def ast(self) -> Ast.Ast:
        """
        Get the abstract syntax tree (AST) of the formula.
        
        Returns
        -------
        Ast.Ast
            The AST of the formula.
        """
        ...
    @property
    def completing_square(self) -> squared_result:
        """
        Complete the square of the formula.
        
        Returns
        -------
        squared_result
            The squared result of the formula.
        """
        ...
    @property
    def degree(self) -> int:
        """
        Get the degree of the formula.
        
        Returns
        -------
        int
            The degree of the formula.
        """
        ...
    @property
    def factorized_elements(self) -> list[Formula]:
        """
        Get the factors of the formula without the degree.
        
        Returns
        -------
        List[Formula]
            The list of factors.
        """
        ...
    @property
    def is_integer(self) -> bool | None:
        """
        Check if the formula is an integer.
        
        Returns
        -------
        Union[bool, None]
            True if the formula is an integer, False otherwise.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the formula.
        
        Returns
        -------
        str
            The text representation of the formula.
        """
        ...
    @property
    def text_factorized(self) -> str:
        """
        Get the factorized text representation of the formula.
        
        Returns
        -------
        str
            The factorized text representation of the formula.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the set of variables in the formula.
        
        Returns
        -------
        set[str]
            The set of variables in the formula.
        """
        ...
    def can_cast(self, type: type[Integer] | type[Float] | type[Fraction]) -> bool:
        """
        Check if the formula can be cast to a specific type.
        
        Parameters
        ----------
        type : Union[type[Integer], type[Float], type[Fraction]]
            The type to cast to.
        
        Returns
        -------
        bool
            True if the formula can be cast to the specified type, False otherwise.
        """
        ...
    def check_for_symmetry(self) -> SymbolicBool:
        """
        Check the symmetry of the formula.
        
        Returns
        -------
        SymbolicBool
            The symbolic boolean indicating if the formula is symmetric.
        """
        ...
    def check_operator(self, check_operator: list[symbol_type]) -> SymbolicBool:
        """
        Check the operators in the formula.
        
        Parameters
        ----------
        check_operator : List[symbol_type]
            The list of operators to check.
        
        Returns
        -------
        SymbolicBool
            The symbolic boolean indicating if the operators are present.
        """
        ...
    def display(self) -> Formula:
        """
        Display the formula.
        
        Returns
        -------
        Formula
            The formula itself.
        """
        ...
    def differentiate(self, focus_variable: str | Formula | None = None) -> Formula:
        """
        Differentiate the formula with respect to a variable.
        
        Parameters
        ----------
        focus_variable : Union[str, Formula, None], optional
            The variable to differentiate with respect to. If None, the formula must have only one variable.
        
        Returns
        -------
        Formula
            The differentiated formula.
        """
        ...
    def expand(self) -> Formula:
        """
        Expand the formula.
        
        Returns
        -------
        Formula
            The expanded formula.
        """
        ...
    def factorize(self) -> Formula:
        """
        Factorize the formula.
        
        Returns
        -------
        Formula
            The factorized formula.
        
        Caution
        -------
        Factorization may fail for terms with only numbers (e.g., 4+4*x). Use factorized_elements instead.
        """
        ...
    def fragile_substitute(self, subsitutee: tuple[str, Formula]) -> Formula:
        """
        Substitute a part of the formula with another formula.
        
        Parameters
        ----------
        subsitutee : Tuple[str, Formula]
            The part to be substituted and the formula to substitute.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def get_coefficients(self, focus_variable: str, should_limit_integer: bool = False) -> list[Formula]:
        """
        Get the coefficients of the formula with respect to a variable.
        
        Parameters
        ----------
        focus_variable : str
            The variable to get coefficients for.
        should_limit_integer : bool, optional
            Whether to limit coefficients to integers.
        
        Returns
        -------
        List[Formula]
            The list of coefficients.
        """
        ...
    def get_factors(self) -> list[Formula]:
        """
        Get the factors of the formula.
        
        Returns
        -------
        List[Formula]
            The list of factors.
        """
        ...
    def identify_from_condition(self, divisor_quantity: int, range: tuple[int, int], section_title: str = '同定する_条件から', section_id: str = 'identify_from_condition') -> Vector:
        """
        Identify the formula from conditions.
        
        Parameters
        ----------
        divisor_quantity : int
            The quantity of divisors.
        range : Tuple[int, int]
            The range for identification.
        section_title : str, optional
            The title of the section.
        section_id : str, optional
            The ID of the section.
        
        Returns
        -------
        Vector
            The identified vector.
        """
        ...
    def integrate(self, focus_variable: str | Formula | None = None) -> Formula:
        """
        Integrate the formula with respect to a variable.
        
        Parameters
        ----------
        focus_variable : Union[str, Formula, None], optional
            The variable to integrate with respect to. If None, the formula must have only one variable.
        
        Returns
        -------
        Formula
            The integrated formula.
        """
        ...
    def is_integer_rough_check(self, rough_search: bool = False, only_positive: bool = True) -> bool | None:
        """
        Roughly check if the formula is an integer.
        
        Parameters
        ----------
        rough_search : bool, optional
            Whether to perform a rough search.
        only_positive : bool, optional
            Whether to consider only positive integers.
        
        Returns
        -------
        Union[bool, None]
            True if the formula is an integer, False otherwise.
        """
        ...
    def is_specific_times(self, times: int, expected_mod: list[int], condition: condition = {'times': 0, 'mod': [0]}, section_title: str = 'proof_specific_times') -> bool:
        """
        Check if the formula is a specific multiple.
        
        Parameters
        ----------
        times : int
            The specific multiple to check.
        expected_mod : List[int]
            The expected modulus.
        condition : condition, optional
            The condition to check.
        section_title : str, optional
            The title of the section.
        
        Returns
        -------
        bool
            True if the formula is the specific multiple, False otherwise.
        """
        ...
    def is_relatively_prime(self, other: Integer | int | Formula, relational_prime_pairs: list[tuple[int | Integer | Formula, int | Integer | Formula]] = []) -> bool | None:
        """
        Check if the formula is relatively prime with another formula.
        
        Parameters
        ----------
        other : Union[Integer, int, Formula]
            The other formula to check against.
        relational_prime_pairs : List[Tuple[Union[int, Integer, Formula], Union[int, Integer, Formula]]], optional
            The list of relational prime pairs.
        
        Returns
        -------
        Union[bool, None]
            True if the formulas are relatively prime, False otherwise.
        """
        ...
    def make_figure(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None = None, title: str = '') -> Figure:
        """
        Create a figure of the formula.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None], optional
            The ranges for plotting.
        title : str, optional
            The title of the plot.
        
        Returns
        -------
        Figure
            The created figure.
        """
        ...
    def make_uni_variantization(self, target_variable: str) -> Formula:
        """
        Make the formula univariate by substituting all variables except the target variable.
        
        Parameters
        ----------
        target_variable : str
            The target variable to keep.
        
        Returns
        -------
        Formula
            The univariate formula.
        """
        ...
    def plot(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None = None, title: str = '', color: hsla = (220, 100, 50), label: str = '') -> Formula: ...
    def proof_powers_modularity(self, mod: int, section_title: str = '乗数の剰余', section_id: str = 'proof_powers_modularity') -> Formula:
        """
        Prove the modularity of powers in the formula.
        
        Parameters
        ----------
        mod : int
            The modulus.
        section_title : str, optional
            The title of the section.
        section_id : str, optional
            The ID of the section.
        
        Returns
        -------
        Formula
            The formula itself.
        """
        ...
    def rough_check_monotonically_increase(self, points: list[int] | None = None, is_in_Natural: bool = True) -> bool | None:
        """
        Roughly check if the formula is monotonically increasing.
        
        Parameters
        ----------
        points : Optional[List[int]], optional
            The points to check.
        is_in_Natural : bool, optional
            Whether to consider only natural numbers.
        
        Returns
        -------
        Union[bool, None]
            True if the formula is monotonically increasing, False otherwise.
        """
        ...
    def solve(self, focus_variable: str | Formula | None = None) -> FormulaVector:
        """
        Solve the formula for a specific variable.
        
        Parameters
        ----------
        focus_variable : Union[str, Formula, None], optional
            The variable to solve for. If None, the formula must have only one variable.
        
        Returns
        -------
        FormulaVector
            The solutions of the formula.
        """
        ...
    def substitute(self, conditions: conditions_float | conditions_int | conditions_str | conditions_term | Equation | Equations) -> Formula:
        """
        Substitute variables in the formula with given conditions.
        
        Parameters
        ----------
        conditions : Union[conditions_float, conditions_int, conditions_str, conditions_term, Equation, Equations]
            The conditions to substitute.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __add__(self, other: float | int | Integer | Float | Fraction | Formula) -> Formula:
        """
        Addition operator.
        
        Parameters
        ----------
        other : Union[float, int, Integer, Float, Fraction, Formula]
            The term to add.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    @overload
    def __eq__(self, other: str) -> str:
        """
        Equality operator.
        
        Parameters
        ----------
        other : Union[term_, str]
            The term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Equation, str]
            The result of the comparison.
        """
        ...
    @overload
    def __eq__(self, other: term_) -> SymbolicBool | Equation: ...
    def __floordiv__(self, other: Formula | float | int | Integer | Float) -> Formula:
        """
        Floor division operator.
        
        Parameters
        ----------
        other : Union[Formula, float, int, Integer, Float]
            The divisor.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the formula.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted formula.
        """
        ...
    def __ge__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Greater than or equal to operator.
        
        Parameters
        ----------
        other : term_
            The term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the comparison.
        """
        ...
    def __gt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Greater than operator.
        
        Parameters
        ----------
        other : term_
            The term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the comparison.
        """
        ...
    def __lt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        ==== jp end ====
        Less than operator.
        
        Parameters
        ----------
        other : term_
            The term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the comparison.
        """
        ...
    def __le__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Less than or equal to operator.
        
        Parameters
        ----------
        other : term_
            The term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the comparison.
        """
        ...
    def __mod__(self, other: Formula | float | int | Integer | Float) -> Formula:
        """
        Modulus operator.
        
        Parameters
        ----------
        other : Union[Formula, float, int, Integer, Float]
            The divisor.
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __mul__(self, other: Formula | float | int | Fraction | Integer | Float) -> Formula:
        """
        Multiplication operator.
        
        Parameters
        ----------
        other : Union[Formula, float, int, Fraction, Integer, Float]
            The term to multiply.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    @overload
    def __ne__(self, other: str) -> str:
        """
        Inequality operator.
        
        Parameters
        ----------
        other : Union[term_, str]
            The term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Unequation, str]
            The result of the comparison.
        """
        ...
    @overload
    def __ne__(self, other: term_) -> SymbolicBool | Unequation: ...
    def __neg__(self) -> Formula:
        """
        Negation operator.
        
        Returns
        -------
        Formula
            The negated formula.
        """
        ...
    def __pow__(self, other: Formula | float | int | Fraction | Integer | Float) -> Formula:
        """
        Power operator.
        
        Parameters
        ----------
        other : Union[Formula, float, int, Fraction, Integer, Float]
            The exponent.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __radd__(self, other: float | int) -> Formula:
        """
        Right addition operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The term to add.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __rfloordiv__(self, other: float | int) -> Formula:
        """
        Right floor division operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The divisor.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __rmod__(self, other: float | int) -> Formula:
        """
        Right modulus operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The divisor.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __rmul__(self, other: float | int) -> Formula:
        """
        Right multiplication operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The term to multiply.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __rpow__(self, other: float | int) -> Formula:
        """
        Right power operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The exponent.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    @overload
    def __rshift__(self, type: type[Float]) -> Float:
        """
        Right shift operator for type casting.
        
        Parameters
        ----------
        type : Union[type[Integer], type[Float], type[Fraction]]
            The type to cast to.
        
        Returns
        -------
        Union[Float, Integer, Fraction]
            The casted term.
        """
        ...
    @overload
    def __rshift__(self, type: type[Fraction]) -> Fraction: ...
    @overload
    def __rshift__(self, type: type[Integer]) -> Integer: ...
    def __rtruediv__(self, other: float | int) -> Formula:
        """
        Right true division operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The term to divide.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __rsub__(self, other: float | int) -> Formula:
        """
        Right subtraction operator.
        
        Parameters
        ----------
        other : Union[float, int]
            The term to subtract.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __sub__(self, other: Formula | float | int | Fraction | Integer | Float) -> Formula:
        """
        Subtraction operator.
        
        Parameters
        ----------
        other : Union[Formula, float, int, Fraction, Integer, Float]
            The term to subtract.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...
    def __truediv__(self, other: Formula | float | int | Fraction | Integer | Float) -> Formula:
        """
        True division operator.
        
        Parameters
        ----------
        other : Union[Formula, float, int, Fraction, Integer, Float]
            The term to divide.
        
        Returns
        -------
        Formula
            The resulting formula.
        """
        ...

 ##### ./tmp/src/formula_utils.py #####

class FormulaUtils:
    """
    式のutilクラス
    """

    @staticmethod
    def adjust_function_left(proof: Proof, formula: Formula, adjust_function: Callable[[variables, str, str | int | float], str], other: Integer | int | Float | float | Fraction | Formula) -> Formula: ...
    @staticmethod
    def adjust_function_right(proof: Proof, formula: Formula, adjust_function: Callable[[variables, str, str | int | float], str], other: Integer | int | Float | float | Fraction | Formula) -> Formula: ...
    @staticmethod
    def identify_from_condition(proof: Proof, formula: Formula, divisor_quantity: int, range: tuple[int, int], section_title: str = '同定する_条件から', section_id: str = 'identify_from_condition') -> Vector: ...
    @staticmethod
    def is_specific_times(proof: Proof, formula: Formula, times: int, expected_mod: list[int], condition: condition = {'times': 0, 'mod': [0]}, section_title: str = 'proof_specific_times') -> bool: ...
    @staticmethod
    def proof_powers_modularity(proof: Proof, formula: Formula, mod: int, section_title: str = '乗数の剰余', section_id: str = 'proof_powers_modularity') -> type['FormulaUtils']: ...
    @staticmethod
    def substitute(proof: Proof, formula: Formula, conditions: conditions_float | conditions_int | conditions_str | conditions_term | Equation | Equations) -> Formula: ...
    @staticmethod
    def subtract_prime(proof: Proof, term: astElement) -> subtract_prime_result: ...
    @staticmethod
    def subtract_term(proof: Proof, formula: Formula, other: Formula) -> tuple[subtract_prime_result, subtract_prime_result]: ...

 ##### ./tmp/src/fraction.py #####

class Fraction:
    """
    Designed math module fraction class.
    """

    def __init__(self, proof: Proof, express: str | express_fraction) -> None:
        """
        Initializes a Fraction instance.
        
        Parameters
        ----------
        proof : Proof
            Proof object associated with the fraction.
        express : Union[str, express_fraction]
            Fraction expression either as a string or as a tuple of numerator and denominator.
        """
        ...
    @property
    def ast(self) -> Ast.Ast:
        """
        Get the abstract syntax tree (AST) of the fraction expression.
        
        Returns
        -------
        Ast.Ast
            The AST of the fraction expression.
        """
        ...
    @property
    def degree(self) -> int:
        """
        Get the highest degree of the polynomial in the fraction.
        
        Returns
        -------
        int
            The highest degree of the polynomial.
        
        Notes
        -----
        Returns correct result only for integer polynomials.
        """
        ...
    @property
    def denominator(self) -> int:
        """
        Get the denominator of the fraction.
        
        Returns
        -------
        int
            The denominator of the fraction.
        """
        ...
    @property
    def is_integer(self) -> bool | None:
        """
        Check if the fraction is an integer.
        
        Returns
        -------
        bool or None
            True if the fraction is an integer, False otherwise.
        """
        ...
    @property
    def number(self) -> int | NativeFraction:
        """
        Get the numeric representation of the fraction.
        
        Returns
        -------
        int or NativeFraction
            The numeric representation of the fraction.
        """
        ...
    @property
    def numerator(self) -> int:
        """
        Get the numerator of the fraction.
        
        Returns
        -------
        int
            The numerator of the fraction.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the fraction.
        
        Returns
        -------
        str
            The text representation of the fraction.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the set of variables in the fraction expression.
        
        Returns
        -------
        set of str
            A set of variable names.
        """
        ...
    def can_cast(self, type: type[Float] | type[Integer]) -> bool:
        """
        Check if the fraction can be cast to a specific type.
        
        Parameters
        ----------
        type : Union[type[Float], type[Integer]]
            The type to which the fraction should be cast.
        
        Returns
        -------
        bool
            True if the fraction can be cast to the specified type, False otherwise.
        """
        ...
    def display(self) -> Fraction:
        """
        Display the fraction.
        
        Returns
        -------
        Fraction
            The fraction itself.
        """
        ...
    def get_coefficients(self, focus_variable: str, should_limit_integer: bool = False) -> list[Fraction]:
        """
        Get the coefficients of the fraction with respect to a focus variable.
        
        Parameters
        ----------
        focus_variable : str
            The variable to focus on.
        should_limit_integer : bool, optional
            Whether to limit the coefficients to integers (default is False).
        
        Returns
        -------
        list of Fraction
            A list of coefficients.
        """
        ...
    @overload
    def __add__(self, formula: Integer | int | Fraction) -> Fraction | Integer:
        """
        Add another term to this fraction.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The term to add.
        
        Returns
        -------
        Union[Formula, Fraction, Integer, Float]
            The result of the addition.
        """
        ...
    @overload
    def __add__(self, formula: Float | float) -> Float: ...
    @overload
    def __add__(self, formula: Formula) -> Formula: ...
    def __eq__(self, other: term_) -> SymbolicBool | Equation:
        """
        Evaluate if this fraction is equal to another term.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Equation]
            Result of the equality evaluation.
        """
        ...
    @overload
    def __floordiv__(self, formula: Integer | int | Float | float | Fraction) -> Integer:
        """
        Perform floor division of this fraction by another term.
        
        Parameters
        ----------
        formula : Union[Formula, float, int, Integer, Float, Fraction]
            The term to divide by using floor division.
        
        Returns
        -------
        Union[Formula, Integer]
            The result of the floor division.
        """
        ...
    @overload
    def __floordiv__(self, formula: Formula) -> Formula: ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the fraction according to a specified format specifier.
        
        Parameters
        ----------
        __format_spec : str
            The format specifier.
        
        Returns
        -------
        str
            The formatted fraction.
        """
        ...
    def __ge__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if this fraction is greater than or equal to another term.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            Result of the greater than or equal evaluation.
        """
        ...
    def __gt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if this fraction is greater than another term.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            Result of the greater than evaluation.
        """
        ...
    def __le__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if this fraction is less than or equal to another term.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            Result of the less than or equal evaluation.
        """
        ...
    def __lt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate if this fraction is less than another term.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            Result of the less than evaluation.
        """
        ...
    @overload
    def __mod__(self, formula: Integer | int | Fraction) -> Integer | Fraction:
        """
        Compute the modulus of this fraction with another term.
        
        Parameters
        ----------
        formula : Union[Formula, float, int, Integer, Float, Fraction]
            The term to compute the modulus with.
        
        Returns
        -------
        Union[Integer, Float, Fraction, Formula]
            The result of the modulus operation.
        """
        ...
    @overload
    def __mod__(self, formula: float | Float) -> Float: ...
    @overload
    def __mod__(self, formula: Formula) -> Formula: ...
    @overload
    def __mul__(self, formula: Integer | int | Fraction) -> Fraction | Integer:
        """
        Multiply this fraction by another term.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The term to multiply by.
        
        Returns
        -------
        Union[Formula, Fraction, Integer, Float]
            The result of the multiplication.
        """
        ...
    @overload
    def __mul__(self, formula: Float | float) -> Float: ...
    @overload
    def __mul__(self, formula: Formula) -> Formula: ...
    def __ne__(self, other: term_) -> SymbolicBool | Unequation:
        """
        Evaluate if this fraction is not equal to another term.
        
        Parameters
        ----------
        other : term_
            The other term to compare with.
        
        Returns
        -------
        Union[SymbolicBool, Unequation]
            Result of the inequality evaluation.
        """
        ...
    def __neg__(self) -> Fraction:
        """
        Negate this fraction.
        
        Returns
        -------
        Fraction
            The negated fraction.
        """
        ...
    def __pow__(self, formula: Integer | int | Float | float | Fraction | Formula) -> Formula:
        """
        Raise this fraction to the power of another term.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The term to raise to the power of.
        
        Returns
        -------
        Formula
            The result of the exponentiation.
        """
        ...
    @overload
    def __radd__(self, formula: int | Integer) -> Fraction | Integer:
        """
        Add this fraction to another term on the right.
        
        Parameters
        ----------
        formula : Union[float, int, Integer]
            The term to add.
        
        Returns
        -------
        Union[Float, Fraction, Integer]
            The result of the addition.
        """
        ...
    @overload
    def __radd__(self, formula: float) -> Float: ...
    @overload
    def __rmod__(self, formula: int | Integer) -> Integer | Fraction:
        """
        Compute the modulus of another term by this fraction on the right.
        
        Parameters
        ----------
        formula : Union[float, int, Integer]
            The term to compute the modulus with.
        
        Returns
        -------
        Union[Integer, Float, Fraction]
            The result of the modulus operation.
        """
        ...
    def __rfloordiv__(self, formula: float | int) -> Integer:
        """
        Perform floor division of another term by this fraction on the right.
        
        Parameters
        ----------
        formula : Union[float, int]
            The term to divide by using floor division.
        
        Returns
        -------
        Integer
            The result of the floor division.
        """
        ...
    @overload
    def __rmod__(self, formula: float) -> Float: ...
    @overload
    def __rmul__(self, formula: int | Integer) -> Fraction | Integer:
        """
        Multiply this fraction by another term on the right.
        
        Parameters
        ----------
        formula : Union[float, int, Integer]
            The term to multiply by.
        
        Returns
        -------
        Union[Float, Fraction, Integer]
            The result of the multiplication.
        """
        ...
    @overload
    def __rmul__(self, formula: float) -> Float: ...
    @overload
    def __rpow__(self, formula: int | Integer) -> Fraction | Integer:
        """
        Raise another term to the power of this fraction on the right.
        
        Parameters
        ----------
        formula : Union[int, Integer, float]
            The term to raise to the power of.
        
        Returns
        -------
        Union[Fraction, Integer, Formula]
            The result of the exponentiation.
        """
        ...
    @overload
    def __rpow__(self, formula: float) -> Formula: ...
    @overload
    def __rshift__(self, type: type[Float]) -> Float:
        """
        Cast the fraction to a specified type.
        
        Parameters
        ----------
        type : Union[type[Float], type[Formula], type[Integer]]
            The type to cast to.
        Returns
        -------
        Union[Formula, Float, Integer]
            The casted fraction.
        """
        ...
    @overload
    def __rshift__(self, type: type[Formula]) -> Formula: ...
    @overload
    def __rshift__(self, type: type[Integer]) -> Integer: ...
    @overload
    def __rsub__(self, formula: int | Integer) -> Fraction | Integer:
        """
        Subtract this fraction from another term on the right.
        
        Parameters
        ----------
        formula : Union[float, int, Integer]
            The term to subtract.
        
        Returns
        -------
        Union[Float, Fraction, Integer]
            The result of the subtraction.
        """
        ...
    @overload
    def __rsub__(self, formula: float) -> Float: ...
    @overload
    def __rtruediv__(self, formula: int | Integer) -> Fraction | Integer:
        """
        Divide another term by this fraction on the right.
        
        Parameters
        ----------
        formula : Union[float, int, Integer]
            The term to divide.
        
        Returns
        -------
        Union[Float, Fraction, Integer]
            The result of the division.
        """
        ...
    @overload
    def __rtruediv__(self, formula: float) -> Float: ...
    @overload
    def __sub__(self, formula: Integer | int | Fraction) -> Fraction | Integer:
        """
        Subtract another term from this fraction.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The term to subtract.
        
        Returns
        -------
        Union[Formula, Fraction, Integer, Float]
            The result of the subtraction.
        """
        ...
    @overload
    def __sub__(self, formula: Float | float) -> Float: ...
    @overload
    def __sub__(self, formula: Formula) -> Formula: ...
    @overload
    def __truediv__(self, formula: Integer | int | Fraction) -> Fraction | Integer:
        """
        Divide this fraction by another term.
        
        Parameters
        ----------
        formula : Union[Integer, int, Float, float, Fraction, Formula]
            The term to divide by.
        
        Returns
        -------
        Union[Formula, Fraction, Integer, Float]
            The result of the division.
        """
        ...
    @overload
    def __truediv__(self, formula: Float | float) -> Float: ...
    @overload
    def __truediv__(self, formula: Formula) -> Formula: ...

express_fraction = Tuple[
        Union[int, float, NativeFraction],
        Union[int, float, NativeFraction],
    ]

 ##### ./tmp/src/inequation.py #####

class Inequation:
    """
    Represents an inequality.
    """

    def __init__(self, proof: Proof, express: str | express_inequation, is_strict_mode: bool = False) -> None:
        """
        Initialize an Inequation instance.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the inequation.
        express : Union[str, express_inequation]
            The expression representing the inequality.
        is_strict_mode : bool, optional
            Indicates if the inequality is strict (default is False).
        """
        ...
    @property
    def degree(self) -> int:
        """
        Get the degree of the inequality.
        
        Returns
        -------
        int
            The maximum degree of the inequality.
        
        Note
        ----
        For non-integer polynomials, the result may not be accurate.
        """
        ...
    @property
    def evaluated(self) -> Inequation | SymbolicBool:
        """
        Evaluate the inequality.
        
        Returns
        -------
        Union[Inequation, SymbolicBool]
            The evaluated inequality.
        """
        ...
    @property
    def formulas(self) -> tuple[Formula, Formula]:
        """
        Get the formulas of the inequality.
        
        Returns
        -------
        Tuple[Formula, Formula]
            The formulas of the inequality.
        """
        ...
    @property
    def solved(self) -> Inequation | SymbolicBool | ComplexCondition:
        """
        Solve the inequality.
        
        Returns
        -------
        Union[Inequation, SymbolicBool, ComplexCondition]
            The solved inequality.
        """
        ...
    @property
    def text(self) -> str:
        """
        Returns the textual representation of the inequation.
        
        Returns
        -------
        str
            The string representation of the inequation.
        """
        ...
    @property
    def text_factorized(self) -> str:
        """
        Get the factorized text of the inequality.
        
        Returns
        -------
        str
            The factorized text of the inequality.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the variables of the inequality.
        
        Returns
        -------
        set[str]
            The variables of the inequality.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of castable types.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    def can_cast(self, type: type_from_term_inequation) -> SymbolicBool:
        """
        Check if the inequality can be cast to the specified type.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to check for casting.
        
        Returns
        -------
        SymbolicBool
            True if the inequality can be cast to the specified type, False otherwise.
        """
        ...
    def factorize(self) -> Inequation:
        """
        Factorize the inequality.
        
        Returns
        -------
        Inequation
            The factorized inequality.
        """
        ...
    def display(self, state: Literal['row', 'factorized', 'factorized_and_split'] = 'factorized_and_split') -> Inequation:
        """
        Display the inequality.
        
        Parameters
        ----------
        state : Literal["row", "factorized", "factorized_and_split"], optional
            The state in which to display the inequality (default is "factorized_and_split").
        
        Returns
        -------
        Inequation
            The displayed inequality.
        """
        ...
    def make_figure(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> Figure:
        """
        Create a figure for the inequality.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges.
        alphabetic_axis_order : bool, optional
            Indicates if the axis order should be alphabetic (default is True).
        title : str, optional
            The title of the figure (default is "").
        
        Returns
        -------
        Figure
            The created figure.
        """
        ...
    def plot(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> SymbolCondition:
        """
        Plot the inequality.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges.
        alphabetic_axis_order : bool, optional
            Indicates if the axis order should be alphabetic (default is True).
        title : str, optional
            The title of the plot (default is “”).
        Returns
        -------
        SymbolCondition
            The plotted inequality.
        """
        ...
    def __and__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Logical AND operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the AND operation.
        
        Returns
        -------
        symbol_condition
            The result of the AND operation.
        """
        ...
    def __eq__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Equality operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the equality check.
        
        Returns
        -------
        SymbolicBool
            The result of the equality check.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the inequality according to the given format spec.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string.
        """
        ...
    def __ge__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater-than-or-equal-to operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the greater-than-or-equal-to comparison.
        
        Returns
        -------
        SymbolicBool
            The result of the greater-than-or-equal-to comparison.
        """
        ...
    def __gt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater-than operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the greater-than comparison.
        
        Returns
        -------
        SymbolicBool
            The result of the greater-than comparison.
        """
        ...
    def __invert__(self) -> symbol_condition:
        """
        Inverts the inequality.
        
        Returns
        -------
        symbol_condition
            The inverted inequality.
        """
        ...
    def __le__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less-than-or-equal-to operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the less-than-or-equal-to comparison.
        
        Returns
        -------
        SymbolicBool
            The result of the less-than-or-equal-to comparison.
        """
        ...
    def __lshift__(self, other: SymbolCondition) -> MathConditional:
        """
        Bitwise left shift operator.
        
        Parameters
        ----------
        other : SymbolCondition
            The operand for the bitwise left shift.
        
        Returns
        -------
        MathConditional
            The result of the bitwise left shift.
        """
        ...
    def __lt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less-than operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the less-than comparison.
        
        Returns
        -------
        SymbolicBool
            The result of the less-than comparison.
        """
        ...
    def __ne__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Inequality operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the inequality check.
        
        Returns
        -------
        SymbolicBool
            The result of the inequality check.
        """
        ...
    def __or__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Logical OR operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the OR operation.
        
        Returns
        -------
        symbol_condition
            The result of the OR operation.
        """
        ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1:
        """
        Right shift operator for casting types.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted type.
        """
        ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2:
        """
        Right shift operator for type casting.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted symbol condition.
        """
        ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition:
        """
        Right shift operator for type casting.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted symbol condition.
        """
        ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...

class Inequation_v1(Inequation):
    """
    Represents an inequality with two variables.
    """

    def __init__(self, proof: Proof, express: str | express_inequation, is_strict_mode: bool = False) -> None:
        """
        Initialize an Inequation_v2 instance.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the inequation.
        express : Union[str, express_inequation]
            The expression representing the inequality.
        is_strict_mode : bool, optional
            Indicates if the inequality is strict (default is False).
        """
        ...
    @property
    def range(self) -> markdown_str:
        """
        Get the range of the inequality.
        
        Returns
        -------
        markdown_str
            The range of the inequality.
        """
        ...
    def can_get_set_integer(self, set_limit: int = 1000, should_raise_error: bool = False) -> bool:
        """
        Check if the inequality can get a set of integers.
        
        Parameters
        ----------
        set_limit : int, optional
            The limit of the set (default is 1000).
        should_raise_error : bool, optional
            Flag indicating if an error should be raised (default is False).
        
        Returns
        -------
        bool
            True if the set of integers can be obtained, False otherwise.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of types the inequality can be cast to.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    def get_set_integer(self, set_limit: int = 1000) -> set[int]:
        """
        Get a set of integers within the specified limit.
        
        Parameters
        ----------
        set_limit : int, optional
            The limit of the set (default is 1000).
        
        Returns
        -------
        set[int]
            The set of integers.
        """
        ...
    def __eq__(self, formula: Inequation_v1) -> bool:
        """
        Equality operator.
        
        Parameters
        ----------
        formula : Inequation_v1
            The formula to compare.
        
        Returns
        -------
        bool
            The result of the equality check.
        """
        ...
    def __ne__(self, formula: Inequation_v1) -> bool:
        """
        Inequality operator.
        
        Parameters
        ----------
        formula : Inequation_v1
            The formula to compare.
        
        Returns
        -------
        bool
            The result of the inequality check.
        """
        ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...
    def __sub__(self, formula: Inequation_v1) -> ComplexCondition_v2 | ComplexCondition_v1 | Equation:
        """
        Subtract an Inequation_v1 object.
        
        Parameters
        ----------
        formula : Inequation_v1
            The formula to subtract.
        
        Returns
        -------
        Union[ComplexCondition_v2, ComplexCondition_v1, Equation]
            The result of the subtraction.
        """
        ...

class Inequation_v2(Inequation):
    """
    Class representing an inequality with two variables.
    """

    def __init__(self, proof: Proof, express: str | express_inequation, is_strict_mode: bool = False) -> None:
        """
        Initialize the Inequation_v2 object.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with this inequation.
        express : Union[str, express_inequation]
            The string representation of the inequation or an expression.
        is_strict_mode : bool, optional
            Flag indicating if the inequation is strict (default is False).
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of castable types.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...
    def __sub__(self, formula: Inequation_v1) -> ComplexCondition_v2 | Equation:
        """
        Subtract another inequality.
        
        Parameters
        ----------
        formula : Inequation_v1
            The inequality to subtract.
        
        Returns
        -------
        Union[ComplexCondition_v2, Equation]
            The result of the subtraction.
        """
        ...

express_inequation = Tuple[term, term]
literal_eq = Literal["="]

 ##### ./tmp/src/integer.py #####

class Integer:
    """
    A class to handle integer operations.
    """

    @staticmethod
    def proof_having_rational_root_2_be_integer(proof: Proof, root: str = 'm', numerator: str = 'q', denominator: str = 'l', section_title: str = '無理数の証明') -> bool:
        """
        Prove that having a rational square root implies the number is an integer.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        root : str, optional
            The root variable (default is "m").
        numerator : str, optional
            The numerator variable (default is "q").
        denominator : str, optional
            The denominator variable (default is "l").
        section_title : str, optional
            The title of the proof section (default is "無理数の証明").
        
        Returns
        -------
        bool
            True if the proof is successful, False otherwise.
        """
        ...
    @staticmethod
    def proof_prime_exist_indefinitely(proof: Proof, section_title: str = '証明する_素数が無限に存在すること', section_id: str = 'proof_prime_exist_indefinitely') -> Integer:
        """
        Prove that prime numbers exist indefinitely.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        section_title : str, optional
            The title of the proof section (default is "証明する_素数が無限に存在すること").
        section_id : str, optional
            The ID of the proof section (default is "proof_prime_exist_indefinitely").
        
        Returns
        -------
        Integer
            An Integer object representing the result of the proof.
        """
        ...
    def __init__(self, proof: Proof, express: int) -> None:
        """
        Initialize an Integer object.
        
        Parameters
        ----------
        proof : Proof
            Proof object associated with the integer.
        express : int
            Integer value.
        """
        ...
    @property
    def ast(self) -> Ast.Ast:
        """
        Get the AST representation.
        
        Returns
        -------
        Ast.Ast
            The AST representation.
        """
        ...
    @property
    def degree(self) -> int:
        """
        Get the highest degree of the expression.
        
        Returns
        -------
        int
            The highest degree of the expression.
        
        Notes
        -----
        The result is not accurate for non-integer polynomials.
        Example: (x**2 + (1/x)**5) -> 5
        """
        ...
    @property
    def divisor_quantity(self) -> Integer:
        """
        Get the number of divisors.
        
        Returns
        -------
        Integer
            The number of divisors.
        """
        ...
    @property
    def divisor_summary(self) -> Integer:
        """
        Get the sum of divisors.
        
        Returns
        -------
        Integer
            The sum of divisors.
        """
        ...
    @property
    def divisors(self) -> list[int]:
        """
        Get the list of divisors.
        
        Returns
        -------
        list of int
            The list of divisors.
        """
        ...
    @property
    def is_integer(self) -> bool | None:
        """
        Check if the expression is an integer.
        
        Returns
        -------
        bool or None
            True if the expression is an integer, None otherwise.
        """
        ...
    @property
    def is_prime(self) -> bool:
        """
        Check if the integer is a prime number.
        
        Returns
        -------
        bool
            True if the integer is a prime number, False otherwise.
        """
        ...
    @property
    def number(self) -> int:
        """
        Get the integer value.
        
        Returns
        -------
        int
            The integer value.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation.
        
        Returns
        -------
        str
            The text representation of the integer.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the set of variables.
        
        Returns
        -------
        set of str
            The set of variables.
        """
        ...
    def can_cast(self, type: type[Float] | type[Fraction]) -> bool:
        """
        Check if the integer can be cast to another type.
        
        Parameters
        ----------
        type : type of Float or type of Fraction
            The type to cast to.
        
        Returns
        -------
        bool
            True if casting is possible, False otherwise.
        """
        ...
    def display(self) -> Integer:
        """
        Display the integer.
        
        Returns
        -------
        Integer
            The Integer object.
        """
        ...
    def get_coefficients(self, focus_variable: str, should_limit_integer: bool = False) -> list[Integer]:
        """
        Get the coefficients of the expression.
        
        Parameters
        ----------
        focus_variable : str
            The variable to focus on.
        should_limit_integer : bool, optional
            Whether to limit to integer coefficients (default is False).
        
        Returns
        -------
        list of Integer
            A list of Integer objects representing the coefficients.
        """
        ...
    def get_powered_residual(self, power: int, mod: int, _range: tuple[int, int] = (1, 5), section_title: str = '乗数の剰余', section_id: str = 'get_powered_residual') -> Formula: ...
    def get_primes_up_to_self(self) -> list[int]:
        """
        Get a list of prime numbers up to the integer value.
        
        Returns
        -------
        list of int
            A list of prime numbers up to the integer value.
        """
        ...
    def get_split_pair_in_to_product(self, uniqueness: Literal['combination', 'order'] = 'order', is_include_minus: bool = False) -> set[tuple[int, int]]:
        """
        Get pairs of integers that multiply to the integer.
        
        Parameters
        ----------
        uniqueness : {'combination', 'order'}, optional
            The uniqueness constraint (default is "order").
        is_include_minus : bool, optional
            Whether to include negative pairs (default is False).
        
        Returns
        -------
        set of tuple of int
            A set of pairs that multiply to the integer.
        """
        ...
    @overload
    def is_relatively_prime(self, other: Integer | int, relational_prime_pairs: list[tuple[int | Integer | Formula, int | Integer | Formula]] = []) -> bool:
        """
        Check if the integer is relatively prime to another integer.
        
        Parameters
        ----------
        other : Union[Integer, int]
            The other integer to check against.
        relational_prime_pairs : list of tuple, optional
            List of pairs to check relative primality (default is []).
        
        Returns
        -------
        bool
            True if the integers are relatively prime, False otherwise.
        """
        ...
    @overload
    def is_relatively_prime(self, other: Formula, relational_prime_pairs: list[tuple[int | Integer | Formula, int | Integer | Formula]] = []) -> bool | None:
        """
        Check if the integer is relatively prime to a formula.
        
        Parameters
        ----------
        other : Formula
            The formula to check against.
        relational_prime_pairs : list of tuple, optional
            List of pairs to check relative primality (default is []).
        
        Returns
        -------
        bool or None
            True if the integer and formula are relatively prime, None otherwise.
        """
        ...
    def prime_factorize(self) -> dict[int, int]:
        """
        Perform prime factorization.
        
        Returns
        -------
        dict of int to int
            A dictionary with prime factors as keys and their exponents as values.
        """
        ...
    @overload
    def __add__(self, other: Integer | int) -> Integer:
        """
        Addition operation.
        
        Parameters
        ----------
        other : Union[Integer, int]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the addition.
        """
        ...
    @overload
    def __add__(self, other: Fraction) -> Fraction:
        """
        Addition operation.
        
        Parameters
        ----------
        other : Fraction
            The other operand.
        
        Returns
        -------
        Fraction
            The result of the addition.
        """
        ...
    @overload
    def __add__(self, other: Float | float) -> Float:
        """
        Addition operation.
        
        Parameters
        ----------
        other : Union[Float, float]
            The other operand.
        
        Returns
        -------
        Float
            The result of the addition.
        """
        ...
    @overload
    def __add__(self, other: Formula) -> Formula:
        """
        Addition operation.
        
        Parameters
        ----------
        other : Formula
            The other operand.
        
        Returns
        -------
        Formula
            The result of the addition.
        """
        ...
    def __eq__(self, term: term_) -> SymbolicBool | Equation:
        """
        Evaluate equality.
        
        Parameters
        ----------
        term : term_
            The term to compare against.
        
        Returns
        -------
        Union[SymbolicBool, Equation]
            The result of the equality evaluation.
        """
        ...
    @overload
    def __floordiv__(self, other: Integer | int | Float | float | Fraction) -> Integer:
        """
        Floor division operation.
        
        Parameters
        ----------
        other : Union[Integer, int, Float, float, Fraction]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the floor division.
        """
        ...
    @overload
    def __floordiv__(self, other: Formula) -> Formula:
        """
        Floor division operation.
        
        Parameters
        ----------
        other : Formula
            The other operand.
        
        Returns
        -------
        Formula
            The result of the floor division.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Return formatted text.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted text.
        """
        ...
    def __ge__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate greater-than-or-equal relationship.
        
        Parameters
        ----------
        other : term_
            The term to compare against.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the greater-than-or-equal evaluation.
        """
        ...
    def __gt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate greater-than relationship.
        
        Parameters
        ----------
        other : term_
            The term to compare against.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the greater-than evaluation.
        """
        ...
    def __le__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate less-than-or-equal relationship.
        
        Parameters
        ----------
        other : term_
            The term to compare against.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the less-than-or-equal evaluation.
        """
        ...
    def __lt__(self, other: term_) -> SymbolicBool | Inequation:
        """
        Evaluate less-than relationship.
        
        Parameters
        ----------
        other : term_
            The term to compare against.
        
        Returns
        -------
        Union[SymbolicBool, Inequation]
            The result of the less-than evaluation.
        """
        ...
    @overload
    def __mod__(self, other: Integer | int) -> Integer:
        """
        Modulo operation.
        
        Parameters
        ----------
        other : Union[Integer, int]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the modulo operation.
        """
        ...
    @overload
    def __mod__(self, other: Fraction) -> Integer | Fraction:
        """
        Modulo operation.
        
        Parameters
        ----------
        other : Fraction
            The other operand.
        
        Returns
        -------
        Union[Integer, Fraction]
            The result of the modulo operation.
        """
        ...
    @overload
    def __mod__(self, other: float | Float) -> Float:
        """
        Modulo operation.
        
        Parameters
        ----------
        other : Union[float, Float]
            The other operand.
        
        Returns
        -------
        Float
            The result of the modulo operation.
        """
        ...
    @overload
    def __mod__(self, other: Formula) -> Formula:
        """
        Modulo operation.
        
        Parameters
        ----------
        other : Formula
            The other operand.
        
        Returns
        -------
        Formula
            The result of the modulo operation.
        """
        ...
    @overload
    def __mul__(self, other: Integer | int) -> Integer:
        """
        Multiplication operation.
        
        Parameters
        ----------
        other : Union[Integer, int]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the multiplication.
        """
        ...
    @overload
    def __mul__(self, other: Fraction) -> Fraction:
        """
        Multiplication operation.
        
        Parameters
        ----------
        other : Fraction
            The other operand.
        
        Returns
        -------
        Fraction
            The result of the multiplication.
        """
        ...
    @overload
    def __mul__(self, other: Float | float) -> Float:
        """
        Multiplication operation.
        
        Parameters
        ----------
        other : Union[Float, float]
            The other operand.
        
        Returns
        -------
        Float
            The result of the multiplication.
        """
        ...
    @overload
    def __mul__(self, other: Formula) -> Formula:
        """
        Multiplication operation.
        
        Parameters
        ----------
        other : Formula
            The other operand.
        
        Returns
        -------
        Formula
            The result of the multiplication.
        """
        ...
    def __ne__(self, other: term_) -> SymbolicBool | Unequation:
        """
        Evaluate inequality.
        
        Parameters
        ----------
        other : term_
            The term to compare against.
        
        Returns
        -------
        Union[SymbolicBool, Unequation]
            The result of the inequality evaluation.
        """
        ...
    def __neg__(self) -> Integer:
        """
        Negation operation.
        
        Returns
        -------
        Integer
            The negated integer.
        """
        ...
    @overload
    def __pow__(self, other: Integer | int) -> Integer:
        """
        Power operation.
        
        Parameters
        ----------
        other : Union[Integer, int]
            The exponent.
        
        Returns
        -------
        Integer
            The result of the power operation.
        """
        ...
    @overload
    def __pow__(self, other: Formula | float | Float | Fraction) -> Formula:
        """
        Power operation.
        
        Parameters
        ----------
        other : Union[Formula, float, Float, Fraction]
            The exponent.
        
        Returns
        -------
        Formula
            The result of the power operation.
        """
        ...
    @overload
    def __radd__(self, other: int | Integer) -> Integer:
        """
        Reverse addition operation.
        
        Parameters
        ----------
        other : Union[int, Integer]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the addition.
        """
        ...
    @overload
    def __radd__(self, other: float) -> Float:
        """
        Reverse addition operation.
        
        Parameters
        ----------
        other : float
            The other operand.
        
        Returns
        -------
        Float
            The result of the addition.
        """
        ...
    def __rfloordiv__(self, other: float | int) -> Integer:
        """
        Implement the reverse floor division operation.
        
        Parameters
        ----------
        other : Union[float, int]
            The value to be used as the divisor in the reverse floor division.
        
        Returns
        -------
        Integer
            The result of the reverse floor division.
        """
        ...
    @overload
    def __rmod__(self, other: int | Integer) -> Integer:
        """
        Reverse modulo operation.
        
        Parameters
        ----------
        other : Union[int, Integer]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the modulo operation.
        """
        ...
    @overload
    def __rmod__(self, other: float) -> Float:
        """
        Reverse modulo operation.
        
        Parameters
        ----------
        other : float
            The other operand.
        
        Returns
        -------
        Float
            The result of the modulo operation.
        """
        ...
    @overload
    def __rmul__(self, other: int | Integer) -> Integer:
        """
        Reverse multiplication operation.
        
        Parameters
        ----------
        other : Union[int, Integer]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the multiplication.
        """
        ...
    @overload
    def __rmul__(self, other: float) -> Float:
        """
        Reverse multiplication operation.
        
        Parameters
        ----------
        other : float
            The other operand.
        
        Returns
        -------
        Float
            The result of the multiplication.
        """
        ...
    @overload
    def __rpow__(self, other: int | Integer) -> Integer:
        """
        Reverse power operation.
        
        Parameters
        ----------
        other : Union[int, Integer]
            The base.
        
        Returns
        -------
        Integer
            The result of the power operation.
        """
        ...
    @overload
    def __rpow__(self, other: float) -> Formula:
        """
        Reverse power operation.
        
        Parameters
        ----------
        other : float
            The base.
        
        Returns
        -------
        Formula
            The result of the power operation.
        """
        ...
    @overload
    def __rshift__(self, type: type[Float]) -> Float:
        """
        Right shift operation.
        
        Parameters
        ----------
        type : type of Float
            The type to cast to.
        
        Returns
        -------
        Float
            The casted object.
        """
        ...
    @overload
    def __rshift__(self, type: type[Formula]) -> Formula:
        """
        Right shift operation.
        
        Parameters
        ----------
        type : type of Formula
            The type to cast to.
        
        Returns
        -------
        Formula
            The casted object.
        """
        ...
    @overload
    def __rshift__(self, type: type[Fraction]) -> Fraction:
        """
        Right shift operation.
        
        Parameters
        ----------
        type : type of Fraction
            The type to cast to.
        
        Returns
        -------
        Fraction
            The casted object.
        """
        ...
    @overload
    def __rshift__(self, type: type[Integer]) -> Integer:
        """
        Right shift operation.
        
        Parameters
        ----------
        type : type of Integer
            The type to cast to.
        
        Returns
        -------
        Integer
            The casted object.
        """
        ...
    @overload
    def __rsub__(self, other: int | Integer) -> Integer:
        """
        Reverse subtraction operation.
        
        Parameters
        ----------
        other : Union[int, Integer]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the subtraction.
        """
        ...
    @overload
    def __rsub__(self, other: float) -> Float:
        """
        Reverse subtraction operation.
        
        Parameters
        ----------
        other : float
            The other operand.
        
        Returns
        -------
        Float
            The result of the subtraction.
        """
        ...
    @overload
    def __rtruediv__(self, other: int | Integer) -> Integer | Fraction:
        """
        Reverse true division operation.
        
        Parameters
        ----------
        other : Union[int, Integer]
            The other operand.
        
        Returns
        -------
        Union[Integer, Fraction]
            The result of the division.
        """
        ...
    @overload
    def __rtruediv__(self, other: float) -> Float:
        """
        Reverse true division operation.
        
        Parameters
        ----------
        other : float
            The other operand.
        
        Returns
        -------
        Float
            The result of the division.
        """
        ...
    @overload
    def __sub__(self, other: Integer | int) -> Integer:
        """
        Subtraction operation.
        
        Parameters
        ----------
        other : Union[Integer, int]
            The other operand.
        
        Returns
        -------
        Integer
            The result of the subtraction.
        """
        ...
    @overload
    def __sub__(self, other: Fraction) -> Fraction:
        """
        Subtraction operation.
        
        Parameters
        ----------
        other : Fraction
            The other operand.
        
        Returns
        -------
        Fraction
            The result of the subtraction.
        """
        ...
    @overload
    def __sub__(self, other: Float | float) -> Float:
        """
        Subtraction operation.
        
        Parameters
        ----------
        other : Union[Float, float]
            The other operand.
        
        Returns
        -------
        Float
            The result of the subtraction.
        """
        ...
    @overload
    def __sub__(self, other: Formula) -> Formula:
        """
        Subtraction operation.
        
        Parameters
        ----------
        other : Formula
            The other operand.
        
        Returns
        -------
        Formula
            The result of the subtraction.
        """
        ...
    @overload
    def __truediv__(self, other: Integer | int | Fraction) -> Fraction | Integer:
        """
        True division operation.
        
        Parameters
        ----------
        other : Union[Integer, int, Fraction]
            The other operand.
        
        Returns
        -------
        Union[Fraction, Integer]
            The result of the division.
        """
        ...
    @overload
    def __truediv__(self, other: Float | float) -> Float:
        """
        True division operation.
        
        Parameters
        ----------
        other : Union[Float, float]
            The other operand.
        
        Returns
        -------
        Float
            The result of the division.
        """
        ...
    @overload
    def __truediv__(self, other: Formula) -> Formula:
        """
        True division operation.
        
        Parameters
        ----------
        other : Formula
            The other operand.
        
        Returns
        -------
        Formula
            The result of the division.
        """
        ...

 ##### ./tmp/src/integer_utils.py #####

class IntegerUtils:
    """
    整数のutilクラス
    """

    @staticmethod
    @overload
    def adjust_function_left(proof: Proof, integer: Integer, adjust_function: Callable[[variables, str, str | int | float], str], other: int | Integer) -> Integer: ...
    @staticmethod
    @overload
    def adjust_function_left(proof: Proof, integer: Integer, adjust_function: Callable[[variables, str, str | int | float], str], other: float) -> Float: ...
    @staticmethod
    @overload
    def adjust_function_right(proof: Proof, integer: Integer, adjust_function: Callable[[variables, str, str | int | float], str], other: Integer | int) -> Integer: ...
    @staticmethod
    @overload
    def adjust_function_right(proof: Proof, integer: Integer, adjust_function: Callable[[variables, str, str | int | float], str], other: Fraction) -> Fraction: ...
    @staticmethod
    @overload
    def adjust_function_right(proof: Proof, integer: Integer, adjust_function: Callable[[variables, str, str | int | float], str], other: Float | float) -> Float: ...
    @staticmethod
    @overload
    def adjust_function_right(proof: Proof, integer: Integer, adjust_function: Callable[[variables, str, str | int | float], str], other: Formula) -> Formula: ...
    @staticmethod
    @overload
    def floordiv__(proof: Proof, integer: Integer, other: Integer | int | Float | float | Fraction) -> Integer:
        """
        [//] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def floordiv__(proof: Proof, integer: Integer, other: Formula) -> Formula:
        """
        [//] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    def get_powered_residual(proof: Proof, integer: Integer, power: int, mod: int, _range: tuple[int, int] = (1, 5), section_title: str = '乗数の剰余', section_id: str = 'get_powered_residual') -> Formula: ...
    @staticmethod
    def get_split_pair_in_to_product(proof: Proof, integer: Integer, uniqueness: Literal['combination', 'order'] = 'order', is_include_minus: bool = False) -> set[tuple[int, int]]: ...
    @staticmethod
    @overload
    def is_relatively_prime(proof: Proof, integer: Integer, other: Formula, relational_prime_pairs: list[tuple[int | Integer | Formula, int | Integer | Formula]] = []) -> bool | None: ...
    @staticmethod
    @overload
    def is_relatively_prime(proof: Proof, integer: Integer, other: Integer | int, relational_prime_pairs: list[tuple[int | Integer | Formula, int | Integer | Formula]] = []) -> bool: ...
    @staticmethod
    @overload
    def mod__(proof: Proof, integer: Integer, other: Integer | int) -> Integer: ...
    @staticmethod
    @overload
    def mod__(proof: Proof, integer: Integer, other: Fraction) -> Integer | Fraction: ...
    @staticmethod
    @overload
    def mod__(proof: Proof, integer: Integer, other: float | Float) -> Float: ...
    @staticmethod
    @overload
    def mod__(proof: Proof, integer: Integer, other: Formula) -> Formula: ...
    @staticmethod
    @overload
    def pow__(proof: Proof, integer: Integer, other: Integer | int) -> Integer:
        """
        [**] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def pow__(proof: Proof, integer: Integer, other: Formula | float | Float | Fraction) -> Formula:
        """
        [**] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    def proof_having_rational_root_2_be_integer(proof: Proof, root: str = 'm', numerator: str = 'q', denominator: str = 'l', section_title: str = 'proof_having_rational_root_2_be_integer') -> bool: ...
    @staticmethod
    def proof_prime_exist_indefinitely(proof: Proof, section_title: str = '素数が無限にある証明', section_id: str = 'proof_prime_exist_indefinitely') -> type['IntegerUtils']: ...
    @staticmethod
    def rfloordiv__(proof: Proof, integer: Integer, other: float | int) -> Integer:
        """
        [//] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def rmod__(proof: Proof, integer: Integer, other: int | Integer) -> Integer:
        """
        [%] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def rmod__(proof: Proof, integer: Integer, other: float) -> Float:
        """
        [%] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def rpow__(proof: Proof, integer: Integer, other: int | Integer) -> Integer:
        """
        [**] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def rpow__(proof: Proof, integer: Integer, other: float) -> Formula:
        """
        [**] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def rtruediv__(proof: Proof, integer: Integer, other: int | Integer) -> Integer | Fraction:
        """
        [/] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def rtruediv__(proof: Proof, integer: Integer, other: float) -> Float:
        """
        [/] の中置演算子
        
        引数:
            other: 式
        結果:
            Formula
        """
        ...
    @staticmethod
    @overload
    def truediv__(proof: Proof, integer: Integer, other: Integer | int | Fraction) -> Fraction | Integer: ...
    @staticmethod
    @overload
    def truediv__(proof: Proof, integer: Integer, other: Formula) -> Formula: ...
    @staticmethod
    @overload
    def truediv__(proof: Proof, integer: Integer, other: Float | float) -> Float: ...

 ##### ./tmp/src/intersect.py #####

class Intersect:
    """
    A class to represent an intersection.
    """

    def __init__(self, proof: Proof, element: set[str]) -> None:
        """
        Initialize the Intersect class.
        
        Parameters
        ----------
        proof : Proof
            The proof object associated with the intersection.
        element : set[str]
            A set of elements involved in the intersection.
        """
        ...
    def display(self) -> Intersect:
        """
        Display the intersection.
        
        Returns
        -------
        Intersect
            The Intersect object itself.
        """
        ...

 ##### ./tmp/src/markdown_contents.py #####

class MarkdownContents:
    """
    A class to represent the contents of Markdown.
    """

    def __init__(self, contents: list[str]) -> None:
        """
        Initialize the MarkdownContents class.
        
        Parameters
        ----------
        contents : List[str]
            The list of strings representing the Markdown content.
        """
        ...
    def display(self, indent_depth: int = 0) -> MarkdownContents:
        """
        Display the Markdown content with the specified indentation depth.
        
        Parameters
        ----------
        indent_depth : int, optional
            The depth of the indentation (default is 0).
        
        Returns
        -------
        MarkdownContents
            The instance of the MarkdownContents class.
        """
        ...

 ##### ./tmp/src/math_conditional.py #####

class MathConditional(Conditional):
    """
    Represents a mathematical proposition described by formulas.
    """

    def __init__(self, sufficient_condition: SymbolCondition, necessary_condition: SymbolCondition, sufficient_condition_bool: bool = True, necessary_condition_bool: bool = True) -> None:
        """
        Initialize a MathConditional object.
        
        Parameters
        ----------
        sufficient_condition : SymbolCondition
            The sufficient condition of the proposition.
        necessary_condition : SymbolCondition
            The necessary condition of the proposition.
        sufficient_condition_bool : bool, optional
            Boolean value for the sufficient condition (default is True).
        necessary_condition_bool : bool, optional
            Boolean value for the necessary condition (default is True).
        """
        ...
    @property
    def contrapositive(self) -> MathConditional:
        """
        Get the contrapositive of the current proposition.
        
        Returns
        -------
        MathConditional
            The contrapositive proposition.
        """
        ...
    @property
    def converse(self) -> MathConditional:
        """
        Get the converse of the current proposition.
        
        Returns
        -------
        MathConditional
            The converse proposition.
        """
        ...
    @property
    def inverse(self) -> MathConditional:
        """
        Get the inverse of the current proposition.
        
        Returns
        -------
        MathConditional
            The inverse proposition.
        """
        ...
    @property
    def opposition(self) -> MathConditional:
        """
        Get the opposition of the current proposition.
        
        Returns
        -------
        MathConditional
            The opposition proposition.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the textual representation of the proposition.
        
        Returns
        -------
        str
            Text representation of the proposition.
        """
        ...
    @property
    def text_necessary_condition(self) -> str:
        """
        Get the text of the necessary condition.
        
        Returns
        -------
        str
            Text of the necessary condition.
        """
        ...
    @property
    def text_sufficient_condition(self) -> str:
        """
        Get the text of the sufficient condition.
        
        Returns
        -------
        str
            Text of the sufficient condition.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the proposition using the given format specification.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            Formatted string representation of the proposition.
        """
        ...

 ##### ./tmp/src/math_markdown_sign.py #####

class MathMarkdownSign:
    """
    Markdownで使用する数学記号のクラス
    """

    @staticmethod
    def annotation() -> str: ...
    @staticmethod
    def because() -> str: ...
    @staticmethod
    def ellipsis() -> str: ...
    @staticmethod
    def full_space() -> str: ...
    @staticmethod
    def half_plus_space() -> str: ...
    @staticmethod
    def half_space() -> str: ...
    @staticmethod
    def therefore() -> str: ...

 ##### ./tmp/src/proof.py #####

class Proof:
    """
    A class to manage explanations and variables in a proof.
    """

    def __init__(self) -> None:
        """
        Initializes the Proof class.
        """
        ...
    @property
    def section_titles(self) -> list[str]:
        """
        Titles of sections in the proof.
        
        Returns
        -------
        List[str]
            A list of section titles.
        """
        ...
    @property
    def variables(self) -> variables:
        """
        Variables in the proof.
        
        Returns
        -------
        variables
            A dictionary of variables.
        """
        ...
    @overload
    def append_explain(self, content: explain, section: str = '') -> Proof:
        """
        Appends an explanation or content to the proof or a specific section.
        
        Parameters
        ----------
        content : Union[explain, relation_content]
            The content to append.
        section : str, optional
            The section to append the content to, by default "".
        is_therefore_sign : bool, optional
            Whether to include a therefore sign, by default False.
        appendix : str, optional
            Additional text to append, by default "".
        appendix_type : Literal["because”, “annotate”, “plain”], optional
            The type of appendix, by default “because”.
        Returns
        -------
        Proof
            The updated Proof object.
        """
        ...
    @overload
    def append_explain(self, content: relation_content, section: str = '', is_therefore_sign: bool = False, appendix: str = '', appendix_type: Literal['because', 'annotate', 'plain'] = 'because') -> Proof: ...
    def display_explain(self, section: str = '') -> Proof:
        """
        Displays the explanations in the proof or a specific section.
        
        Parameters
        ----------
        section : str, optional
            The section to display, by default "".
        
        Returns
        -------
        Proof
            The updated Proof object.
        """
        ...
    def get_section(self, title: str) -> Section:
        """
        Gets the section with the specified title.
        
        Parameters
        ----------
        title : str
            The title of the section to retrieve.
        
        Returns
        -------
        Section
            The section with the specified title.
        """
        ...
    @overload
    def get_variable(self, variable: list[str] | set[str]) -> list[Formula]:
        """
        Retrieves variable(s) as Formula object(s).
        
        Parameters
        ----------
        variable : Union[str, List[str], set[str]]
            The variable name(s) to retrieve.
        
        Returns
        -------
        Union[Formula, List[Formula]]
            A Formula object or a list of Formula objects.
        """
        ...
    @overload
    def get_variable(self, variable: str) -> Formula: ...
    def insert_section(self, section: Section | str, parent_section: str | Section | None = None) -> Proof:
        """
        Inserts a section into the proof, optionally under a parent section.
        
        Parameters
        ----------
        section : Union[Section, str]
            The section to insert.
        parent_section : Union[str, Section, None], optional
            The parent section to insert under, by default None.
        
        Returns
        -------
        Proof
            The updated Proof object.
        """
        ...
    def is_variable(self, express: Formula | str) -> bool:
        """
        Checks if the given expression is a variable in the proof.
        
        Parameters
        ----------
        express : Union[Formula, str]
            The expression to check.
        
        Returns
        -------
        bool
            True if the expression is a variable, False otherwise.
        """
        ...
    def make_section(self, title: str, id: str) -> Section:
        """
        Creates a new section with the specified title and ID.
        
        Parameters
        ----------
        title : str
            The title of the section.
        id : str
            The ID of the section.
        
        Returns
        -------
        Section
            The created section.
        """
        ...
    def make_temporary_section_id(self, base_id: str) -> str:
        """
        Creates a unique temporary section ID based on the given base ID.
        
        Parameters
        ----------
        base_id : str
            The base ID to generate the temporary section ID from.
        
        Returns
        -------
        str
            A unique temporary section ID.
        """
        ...
    def make_temporary_variable(self) -> Formula:
        """
        Creates a temporary variable with a unique name.
        
        Returns
        -------
        Formula
            A Formula object representing the temporary variable.
        """
        ...
    @overload
    def make_variable(self, variables: str, variable_types: variable_type_optional | variable_types_optional = {}) -> Formula:
        """
        Creates one or more variables with optional types.
        
        Parameters
        ----------
        variables : Union[str, List[str]]
            The variable name(s) to create.
        variable_types : Union[variable_type_optional, variable_types_optional], optional
            The types of the variables, by default {}.
        
        Returns
        -------
        Union[Formula, List[Formula]]
            A Formula object or a list of Formula objects representing the created variables.
        """
        ...
    @overload
    def make_variable(self, variables: variables_list, variable_types: variable_type_optional | variable_types_optional = {}) -> formulas: ...
    def make_variables(self, variables: str, variable_types: variable_type_optional | variable_types_optional = {}) -> formulas:
        """
        Creates multiple variables from a comma or space-separated string.
        
        Parameters
        ----------
        variables : str
            A comma or space-separated string of variable names.
        variable_types : Union[variable_type_optional, variable_types_optional], optional
            The types of the variables, by default {}.
        
        Returns
        -------
        List[Formula]
            A list of Formula objects representing the created variables.
        """
        ...
    def register_variables(self, variables: list[str], variable_types: variable_types_optional = {}) -> Proof:
        """
        Registers variables with optional types.
        
        Parameters
        ----------
        variables : List[str]
            A list of variable names to register.
        variable_types : variable_types_optional, optional
            The types of the variables, by default {}.
        
        Returns
        -------
        Proof
            The updated Proof object.
        """
        ...
    def update_variables(self, variables: variables) -> Proof:
        """
        Updates the variables in the proof.
        
        Parameters
        ----------
        variables : variables
            A dictionary of variables to update.
        
        Returns
        -------
        Proof
            The updated Proof object.
        """
        ...
variables_list = list[str]
variables_set = set[str]
formulas = List[Formula]

 ##### ./tmp/src/py_utils.py #####

#


#

# default_range: 

class PyUtils:


    @staticmethod
    def display_safety(contents: str | Markdown | Math) -> None: ...
    @overload
    @staticmethod
    def get_all_combination(choices: list[list[int]]) -> list[list[int]]: ...
    @overload
    @staticmethod
    def get_all_combination(choices: list[list[float]]) -> list[list[float]]: ...
    @overload
    @staticmethod
    def get_all_combination(choices: list[list[str]]) -> list[list[str]]: ...
    @staticmethod
    def get_random_name(n: int, lower_case: bool) -> str: ...
    @staticmethod
    def is_float(string: str) -> bool: ...
    @staticmethod
    def is_fraction(string: str) -> bool: ...
    @staticmethod
    def is_integer(string: str) -> bool: ...
    @staticmethod
    def is_num(string: str) -> bool: ...
    @staticmethod
    def translate_range_from_dict_to_tuple(plot_ranges: plotRanges, alphabetic_axis_order: bool = True, variables: set[str] = set()) -> plotRange_2d: ...
    @staticmethod
    def translate_range_from_single_to_twin(plot_range: plotRange) -> plotRange_2d: ...
    @staticmethod
    def translate_range_to_plotRange_2d(plot_ranges: None | plotRanges | plotRange | plotRange_2d, alphabetic_axis_order: bool = True, variables: set[str] = set()) -> plotRange_2d: ...

 ##### ./tmp/src/relation_content.py #####

class RelationContent:
    """
    Class representing Markdown content that has relationships with preceding and following content.
    """

    def __init__(self, content: relation_content, is_therefore_sign: bool = False, appendix: str = '', appendix_type: Literal['because', 'annotate', 'plain'] = 'because') -> None:
        """
        Initialize a RelationContent instance.
        
        Parameters
        ----------
        content : relation_content
            The main content.
        is_therefore_sign : bool, optional
            Whether the therefore sign is present (default is False).
        appendix : str, optional
            Additional text to append (default is an empty string).
        appendix_type : Literal["because", "annotate", "plain"], optional
            Type of the appendix (default is "because").
        """
        ...
    @property
    def ascended_therefore_sign(self) -> bool:
        """
        Check if the therefore sign is ascended.
        
        Returns
        -------
        bool
            True if the therefore sign is ascended, False otherwise.
        """
        ...
    @property
    def content(self) -> relation_content:
        """
        Get the content.
        
        Returns
        -------
        relation_content
            The main content.
        """
        ...
    def display(self, indent_depth: int = 0, previous_content: RelationContent | None = None, omit_mode: Literal['off', 'on', 'auto'] = 'auto') -> RelationContent:
        """
        Display the content with formatting.
        
        Parameters
        ----------
        indent_depth : int, optional
            Depth of indentation (default is 0).
        previous_content : Union[RelationContent, None], optional
            Previous content for context (default is None).
        omit_mode : Literal["off", "on", "auto"], optional
            Mode for omitting repeated content (default is "auto").
        
        Returns
        -------
        RelationContent
            The RelationContent instance for chaining.
        """
        ...

 ##### ./tmp/src/section.py #####

class Section:
    """
    Class representing a section in a proof document.
    
    Attributes:
    -----------
    id : str
        The identifier for the section.
    
    Parameters:
    -----------
    proof : Proof
        The proof object this section belongs to.
    title : str
        The title of the section.
    id : str
        The identifier for the section.
    """

    @overload
    def append(self, content: explain, is_therefore_sign: bool = False) -> Section:
        """
        Append content to the section.
        
        Parameters:
        -----------
        content : Union[explain, relation_content]
            The content to append.
        is_therefore_sign : bool, optional
            Whether to include a therefore sign.
        appendix : str, optional
            The appendix text.
        appendix_type : Literal["because", "annotate", "plain"], optional
            The type of the appendix.
        
        Returns:
        --------
        Section
            The section with the appended content.
        """
        ...
    @overload
    def append(self, content: relation_content, is_therefore_sign: bool = False, appendix: str = '', appendix_type: Literal['because', 'annotate', 'plain'] = 'because') -> Section: ...
    def display(self, indent_depth: int = 0) -> Section:
        """
        Display the section.
        
        Parameters:
        -----------
        indent_depth : int, optional
            The depth of the indentation.
        
        Returns:
        --------
        Section
            The section itself.
        """
        ...
    def insert_section(self, section: Section | str) -> Section:
        """
        Insert a section.
        
        Parameters:
        -----------
        section : Union[Section, str]
            The section to insert.
        
        Returns:
        --------
        Section
            The section with the inserted section.
        """
        ...
    def make_sub_section(self, title: str, id: str, index: int | None = None) -> Section:
        """
        Create a sub-section.
        
        Parameters:
        -----------
        title : str
            The title of the sub-section.
        id : str
            The identifier for the sub-section.
        index : Union[int, None], optional
            The index to insert the sub-section at. If None, appends to the end.
        
        Returns:
        --------
        Section
            The created sub-section.
        """
        ...
    def __getitem__(self, index: int) -> explain:
        """
        Get the content at the specified index.
        
        Parameters:
        -----------
        index : int
            The index of the content to retrieve.
        
        Returns:
        --------
        explain
            The content at the specified index.
        """
        ...
    def __init__(self, proof: Proof, title: str, id: str) -> None: ...
    def __iter__(self) -> Generator[explain, None, None]:
        """
        Iterate over the contents.
        
        Yields:
        -------
        explain
            The next content in the section.
        """
        ...
    @overload
    def __setitem__(self, index: int, value: Section) -> Section:
        """
        Set the content at the specified index.
        
        Parameters:
        -----------
        index : int
            The index of the content to set.
        value : Union[Section, RelationContent]
            The content to set.
        
        Returns:
        --------
        Union[Section, RelationContent]
            The set content.
        """
        ...
    @overload
    def __setitem__(self, index: int, value: RelationContent) -> RelationContent: ...

 ##### ./tmp/src/symbol_condition_utils.py #####

class SymbolConditionUtils:
    """
    数式の論理結合演算子操作をまとめたクラス
    
    Attributes:
        variables (set[str]): 条件中で用いられる変数
        text (str): 条件中で用いられる変数
    """

    @staticmethod
    def and__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> symbol_condition:
        """
        論理和の中置演算子
        
        Args:
            other : 演算対象
        """
        ...
    @staticmethod
    def display(proof: Proof, condition: SymbolCondition) -> type['SymbolConditionUtils']: ...
    @staticmethod
    def eq__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> SymbolicBool: ...
    @staticmethod
    def format__(condition: SymbolCondition) -> str: ...
    @staticmethod
    def ge__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> SymbolicBool: ...
    @staticmethod
    def gt__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> SymbolicBool: ...
    @staticmethod
    def invert__(proof: Proof, condition_left: SymbolCondition) -> symbol_condition: ...
    @staticmethod
    def le__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> SymbolicBool: ...
    @staticmethod
    def lt__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> SymbolicBool: ...
    @staticmethod
    def lshift__(condition_left: SymbolCondition, condition_right: SymbolCondition) -> MathConditional: ...
    @staticmethod
    def make_figure(proof: Proof, condition: SymbolCondition, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> Figure: ...
    @staticmethod
    def ne__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> SymbolicBool: ...
    @staticmethod
    def or__(proof: Proof, condition_left: SymbolCondition, condition_right: bool | symbol_condition) -> symbol_condition: ...
    @staticmethod
    def plot(proof: Proof, condition: SymbolCondition, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> type['SymbolConditionUtils']: ...

 ##### ./tmp/src/symbolic_bool.py #####

class SymbolicBool:
    """
    A boolean class for use in mathematical modules instead of the native python bool.
    """

    def __init__(self, proof: Proof, bool: bool) -> None:
        """
        Initialize the SymbolicBool object.
        
        Parameters
        ----------
        proof : Proof
            The proof associated with this boolean.
        bool : bool
            The boolean value.
        """
        ...
    @property
    def native_bool(self) -> bool:
        """
        Get the native boolean value.
        
        Returns
        -------
        bool
            The native boolean value.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the SymbolicBool.
        
        Returns
        -------
        str
            The text representation.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the set of variables associated with this SymbolicBool.
        
        Returns
        -------
        set[str]
            The set of variables.
        """
        ...
    def can_cast(self, type: type_from_term_inequation) -> SymbolicBool:
        """
        Check if the SymbolicBool can be cast to a given type.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to check casting to.
        
        Returns
        -------
        SymbolicBool
            The result of the cast check.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of types to which this SymbolicBool can be cast.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    def display(self) -> SymbolicBool:
        """
        Display the SymbolicBool.
        
        Returns
        -------
        SymbolicBool
            The displayed SymbolicBool.
        """
        ...
    def make_figure(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> Figure:
        """
        Make a figure based on the SymbolicBool.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to use alphabetic axis order, by default True.
        title : str, optional
            The title of the figure, by default "".
        
        Returns
        -------
        Figure
            The created figure.
        """
        ...
    def plot(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> SymbolCondition:
        """
        Plot the SymbolicBool.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to use alphabetic axis order, by default True.
        title : str, optional
            The title of the figure, by default "".
        
        Returns
        -------
        SymbolCondition
            The plotted condition.
        """
        ...
    @overload
    def __and__(self, other: bool | SymbolicBool) -> SymbolicBool:
        """
        Logical AND operation for SymbolicBool.
        
        Parameters
        ----------
        other : Union[bool, SymbolicBool, symbol_range]
            The other value to perform AND with.
        
        Returns
        -------
        symbol_condition
            The result of the AND operation.
        """
        ...
    @overload
    def __and__(self, other: symbol_range) -> symbol_condition: ...
    def __bool__(self) -> bool:
        """
        Boolean conversion for SymbolicBool.
        
        Returns
        -------
        bool
            The native boolean value.
        """
        ...
    def __eq__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Equality comparison for SymbolicBool.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other value to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the equality comparison.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the SymbolicBool according to the given format specification.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string.
        """
        ...
    def __ge__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater than or equal comparison between this SymbolicBool and another.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other value to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __gt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater than comparison between this SymbolicBool and another.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other value to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __invert__(self) -> SymbolicBool:
        """
        Invert the SymbolicBool.
        
        Returns
        -------
        SymbolicBool
            The inverted SymbolicBool.
        """
        ...
    def __le__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less than or equal comparison between this SymbolicBool and another.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other value to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __lshift__(self, other: SymbolCondition) -> MathConditional:
        """
        Left shift operator for SymbolicBool.
        
        Parameters
        ----------
        other : SymbolCondition
            The other condition to shift with.
        
        Returns
        -------
        MathConditional
            The result of the left shift.
        """
        ...
    def __lt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less than comparison between this SymbolicBool and another.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other value to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the comparison.
        """
        ...
    def __ne__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Inequality comparison for SymbolicBool.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The other value to compare with.
        
        Returns
        -------
        SymbolicBool
            The result of the inequality comparison.
        """
        ...
    @overload
    def __or__(self, other: bool | SymbolicBool) -> SymbolicBool:
        """
        Logical OR operation for SymbolicBool.
        
        Parameters
        ----------
        other : Union[bool, SymbolicBool, symbol_range]
            The other value to perform OR with.
        
        Returns
        -------
        symbol_condition
            The result of the OR operation.
        """
        ...
    @overload
    def __or__(self, other: symbol_range) -> symbol_condition: ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool:
        """
        Right shift operator for SymbolicBool.
        
        Parameters
        ----------
        type : Union[type_from_term_inequation, ExplainEquation, DefineEquation]
            The type to shift with.
        
        Returns
        -------
        Union[symbol_condition, ExplainEquation, DefineEquation]
            The result of the right shift.
        """
        ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[DefineEquation]) -> DefineEquation: ...
    @overload
    def __rshift__(self, type: type[ExplainEquation]) -> ExplainEquation: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...

 ##### ./tmp/src/table.py #####

class Table:
    """
    A class representing a table that can be displayed in markdown.
    """

    def __init__(self, data: table_data) -> None:
        """
        Initialize the Table with data.
        
        Parameters
        ----------
        data : table_data
            The data to initialize the table with.
        """
        ...
    @property
    def data(self) -> table_data:
        """
        Get the table data.
        
        Returns
        -------
        table_data
            The data of the table.
        """
        ...
    def add_column(self, columnName: str | int | float, body: list[str | int | float]) -> Table:
        """
        Add a column to the table.
        
        Parameters
        ----------
        columnName : Union[str, int, float]
            The name of the new column.
        body : list of Union[str, int, float]
            The data for the new column.
        
        Returns
        -------
        Table
            The table with the new column added.
        """
        ...
    def add_row(self) -> Table:
        """
        Add a row to the table. Not yet implemented.
        
        Returns
        -------
        Table
            The table with the new row.
        """
        ...
    def display(self) -> Table:
        """
        Display the table.
        
        Returns
        -------
        Table
            The displayed table.
        """
        ...
    def remove_display_limit(self, direction: Literal['row', 'column']) -> Table:
        """
        Remove display limit in the specified direction.
        
        Parameters
        ----------
        direction : {'row', 'column'}
            The direction in which to remove the display limit.
        
        Returns
        -------
        Table
            The table with the display limit removed.
        """
        ...
    def set_index(self, columnName: str) -> Table:
        """
        Set the index of the table to the specified column.
        
        Parameters
        ----------
        columnName : str
            The name of the column to set as index.
        
        Returns
        -------
        Table
            The table with the index set.
        """
        ...

 ##### ./tmp/src/term_utils.py #####

class TermUtils:
    """
    designed math(数式処理)モジュールでの項に関するユーティリティクラス
    """

    @staticmethod
    def check_be_integer(proof: Proof, term: Term) -> bool | None: ...
    @staticmethod
    def display(proof: Proof, term: Term) -> type['TermUtils']: ...
    @staticmethod
    def evaluate_equality(proof: Proof, term_left: Term, term_right: term_) -> SymbolicBool | Equation: ...
    @staticmethod
    def evaluate_greater_or_equality(proof: Proof, term_left: Term, term_right: term_) -> SymbolicBool | Inequation: ...
    @staticmethod
    def evaluate_greater_than_relation(proof: Proof, term_left: Term, term_right: term_) -> SymbolicBool | Inequation: ...
    @staticmethod
    def evaluate_less_or_equality(proof: Proof, term_left: Term, term_right: term_) -> SymbolicBool | Inequation: ...
    @staticmethod
    def evaluate_less_than_relation(proof: Proof, term_left: Term, term_right: term_) -> SymbolicBool | Inequation: ...
    @staticmethod
    def evaluate_not_equality(proof: Proof, term_left: Term, term_right: term_) -> SymbolicBool | Unequation: ...
    @staticmethod
    def get_degree(proof: Proof, term: Term) -> int:
        """
        式の最大の次数
        
        注意:
            整数多項式以外は、正しい結果を返さない。
            例）(x**2 + (1/x)**5) -> 5
        """
        ...
    @staticmethod
    def get_formatted_text(term: Term) -> str: ...
    @staticmethod
    def get_stringify_text(term: Term) -> str: ...

 ##### ./tmp/src/text_conditional.py #####

class TextConditional(Conditional):
    """
    Class representing a proposition in natural language.
    """

    def __init__(self, sufficient_condition: str, necessary_condition: str, sufficient_condition_bool: bool = True, necessary_condition_bool: bool = True) -> None:
        """
        Initialize the TextConditional.
        
        Parameters
        ----------
        sufficient_condition : str
            The sufficient condition of the proposition.
        necessary_condition : str
            The necessary condition of the proposition.
        sufficient_condition_bool : bool, optional
            Boolean value of the sufficient condition, by default True.
        necessary_condition_bool : bool, optional
            Boolean value of the necessary condition, by default True.
        """
        ...
    @property
    def converse(self) -> TextConditional:
        """
        Get the converse proposition.
        
        Returns
        -------
        TextConditional
            The converse proposition.
        """
        ...
    @property
    def contrapositive(self) -> TextConditional:
        """
        Get the contrapositive proposition.
        
        Returns
        -------
        TextConditional
            The contrapositive proposition.
        """
        ...
    @property
    def inverse(self) -> TextConditional:
        """
        Get the inverse proposition.
        
        Returns
        -------
        TextConditional
            The inverse proposition.
        """
        ...
    @property
    def opposition(self) -> TextConditional:
        """
        Get the opposition proposition.
        
        Returns
        -------
        TextConditional
            The opposition proposition.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the proposition.
        
        Returns
        -------
        str
            The text representation of the proposition.
        """
        ...
    @property
    def text_contrapositive(self) -> str:
        """
        Get the text representation of the contrapositive proposition.
        
        Returns
        -------
        str
            The text representation of the contrapositive proposition.
        """
        ...
    @property
    def text_converse(self) -> str:
        """
        Get the text representation of the converse proposition.
        
        Returns
        -------
        str
            The text representation of the converse proposition.
        """
        ...
    @property
    def text_inverse(self) -> str:
        """
        Get the text representation of the inverse proposition.
        
        Returns
        -------
        str
            The text representation of the inverse proposition.
        """
        ...
    @property
    def text_necessary_condition(self) -> str:
        """
        Get the text representation of the necessary condition.
        
        Returns
        -------
        str
            The text representation of the necessary condition.
        """
        ...
    @property
    def text_opposition(self) -> str:
        """
        Get the text representation of the opposition proposition.
        
        Returns
        -------
        str
            The text representation of the opposition proposition.
        """
        ...
    @property
    def text_sufficient_condition(self) -> str:
        """
        Get the text representation of the sufficient condition.
        
        Returns
        -------
        str
            The text representation of the sufficient condition.
        """
        ...

 ##### ./tmp/src/unequation.py #####

class Unequation:
    """
    Unequation class to represent non-equation (inequality).
    Derived from equations and inequalities.
    """

    def __init__(self, proof: Proof, equation: str | express_term) -> None:
        """
        Initialize Unequation instance.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        equation : Union[str, express_term]
            The equation string or term tuple representing the unequation.
        """
        ...
    @property
    def evaluated(self) -> Unequation | SymbolicBool:
        """
        Evaluate the Unequation.
        
        Returns
        -------
        Union[Unequation, SymbolicBool]
            The evaluated Unequation or a SymbolicBool.
        """
        ...
    @property
    def formulas(self) -> tuple[Formula, Formula]:
        """
        Get the formulas of the Unequation.
        
        Returns
        -------
        Tuple[Formula, Formula]
            The formulas of the Unequation.
        """
        ...
    @property
    def text_for_display(self) -> str:
        """
        Get the display text of the Unequation.
        
        Returns
        -------
        str
            The display text of the Unequation.
        """
        ...
    @property
    def text_for_input(self) -> str:
        """
        Get the input text of the Unequation.
        
        Returns
        -------
        str
            The input text of the Unequation.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Get the variables of the Unequation.
        
        Returns
        -------
        set[str]
            The variables of the Unequation.
        """
        ...
    @property
    def text(self) -> str:
        """
        Get the text representation of the Unequation.
        
        Returns
        -------
        str
            Text representation of the Unequation.
        """
        ...
    def can_cast(self, type: type_from_term_inequation) -> SymbolicBool:
        """
        Check if the Unequation can be cast to a specific type.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to check for casting.
        
        Returns
        -------
        SymbolicBool
            True if the Unequation can be cast to the specified type, False otherwise.
        """
        ...
    def castable_type(self) -> list[type_from_term_inequation]:
        """
        Get the list of castable types.
        
        Returns
        -------
        List[type_from_term_inequation]
            The list of castable types.
        """
        ...
    def display(self, is_raw: bool = True) -> Unequation:
        """
        Display the Unequation.
        
        Parameters
        ----------
        is_raw : bool, optional
            Whether to display the raw unequation (default is True).
        
        Returns
        -------
        Unequation
            The displayed Unequation.
        """
        ...
    def factorize(self) -> Unequation:
        """
        Factorize the Unequation.
        
        Returns
        -------
        Unequation
            The factorized Unequation.
        """
        ...
    def is_identity(self) -> bool:
        """
        Check if the Unequation is an identity.
        
        Returns
        -------
        bool
            True if the Unequation is an identity, False otherwise.
        """
        ...
    def make_figure(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> Figure:
        """
        Create a figure for the Unequation.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges for the figure.
        alphabetic_axis_order : bool, optional
            Whether to use alphabetic order for the axes (default is True).
        title : str, optional
            The title of the figure (default is "").
        
        Returns
        -------
        Figure
            The created figure.
        """
        ...
    def plot(self, plot_ranges: plotRange | plotRanges | plotRange_2d | None, alphabetic_axis_order: bool = True, title: str = '') -> SymbolCondition:
        """
        Plot the Unequation.
        
        Parameters
        ----------
        plot_ranges : Union[plotRange, plotRanges, plotRange_2d, None]
            The plot ranges for the plot.
        alphabetic_axis_order : bool, optional
            Whether to use alphabetic order for the axes (default is True).
        title : str, optional
            The title of the plot (default is "").
        
        Returns
        -------
        SymbolCondition
            The plotted SymbolCondition.
        """
        ...
    def substitute(self, conditions: dict[str, float] | dict[str, int] | dict[str, Term] | Equation | Equations, side: Literal['left', 'right'] | None = None) -> Unequation:
        """
        Substitute conditions into the Unequation.
        
        Parameters
        ----------
        conditions : Union[Dict[str, float], Dict[str, int], Dict[str, Term], Equation, Equations]
            The conditions for substitution.
        side : Union[Literal["left", "right"], None], optional
            The side of the unequation to substitute (default is None).
        
        Returns
        -------
        Unequation
            The resulting Unequation after substitution.
        """
        ...
    def __and__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Logical AND operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the AND operation.
        
        Returns
        -------
        symbol_condition
            The result of the AND operation.
        """
        ...
    def __eq__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Equality operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the equality operation.
        
        Returns
        -------
        SymbolicBool
            The result of the equality operation.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Format the Unequation.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            Formatted string.
        """
        ...
    def __ge__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater than or equal to operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the greater than or equal to operation.
        
        Returns
        -------
        SymbolicBool
            The result of the greater than or equal to operation.
        """
        ...
    def __gt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Greater than operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the greater than operation.
        
        Returns
        -------
        SymbolicBool
            The result of the greater than operation.
        """
        ...
    def __invert__(self) -> symbol_condition:
        """
        Logical NOT operator.
        
        Returns
        -------
        symbol_condition
            The result of the NOT operation.
        """
        ...
    def __le__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less than or equal to operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the less than or equal to operation.
        
        Returns
        -------
        SymbolicBool
            The result of the less than or equal to operation.
        """
        ...
    def __lshift__(self, other: SymbolCondition) -> MathConditional:
        """
        Left shift operator.
        
        Parameters
        ----------
        other : SymbolCondition
            The operand for the left shift operation.
        
        Returns
        -------
        MathConditional
            The result of the left shift operation.
        """
        ...
    def __lt__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Less than operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the less than operation.
        
        Returns
        -------
        SymbolicBool
            The result of the less than operation.
        """
        ...
    def __ne__(self, other: bool | symbol_condition) -> SymbolicBool:
        """
        Inequality operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the inequality operation.
        
        Returns
        -------
        SymbolicBool
            The result of the inequality operation.
        """
        ...
    def __or__(self, other: bool | symbol_condition) -> symbol_condition:
        """
        Logical OR operator.
        
        Parameters
        ----------
        other : Union[bool, symbol_condition]
            The operand for the OR operation.
        
        Returns
        -------
        symbol_condition
            The result of the OR operation.
        """
        ...
    @overload
    def __rshift__(self, type: type[SymbolicBool]) -> SymbolicBool:
        """
        Right shift operator for type casting.
        
        Parameters
        ----------
        type : type_from_term_inequation
            The type to cast to.
        
        Returns
        -------
        symbol_condition
            The casted symbol condition.
        """
        ...
    @overload
    def __rshift__(self, type: type[Inequation_v1]) -> Inequation_v1: ...
    @overload
    def __rshift__(self, type: type[Inequation_v2]) -> Inequation_v2: ...
    @overload
    def __rshift__(self, type: type[Inequation]) -> Inequation: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v1]) -> ComplexCondition_v1: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition_v2]) -> ComplexCondition_v2: ...
    @overload
    def __rshift__(self, type: type[ComplexCondition]) -> ComplexCondition: ...
    @overload
    def __rshift__(self, type: type[Equation]) -> Equation: ...
    @overload
    def __rshift__(self, type: type[Unequation]) -> Unequation: ...

 ##### ./tmp/src/utils.py #####

class Utils:
    """
    designed math モジュールでのutilityクラス
    """

    @staticmethod
    def can_cast(type: term_type, text: str) -> bool: ...
    @staticmethod
    def cast(proof: Proof, type: term_type, text: str) -> Integer | Float | Fraction | Formula: ...
    @staticmethod
    def condition_logical_and(proof: Proof, conditions: tuple[symbol_condition, symbol_condition]) -> symbol_condition: ...
    @staticmethod
    def condition_logical_or(proof: Proof, conditions: tuple[symbol_condition, symbol_condition]) -> symbol_condition: ...
    @staticmethod
    def display(contents: str | Markdown) -> None: ...
    @staticmethod
    def display_row_express(proof: Proof, express: str) -> None:
        """
        式を評価せずに表示する
        要改修:
            ()が評価されて消えてしまう。
            x/xは評価されて1になってしまう。（変数宣言する必要あり）
        """
        ...
    @staticmethod
    @overload
    def euclideanAlgorithm(proof: Proof, terms: tuple[int, int], section_title: str) -> tuple[int, int]: ...
    @staticmethod
    @overload
    def euclideanAlgorithm(proof: Proof, terms: tuple[str, str], section_title: str) -> tuple[str, str]: ...
    @staticmethod
    def get_called_location() -> int:
        """
        関数の呼び出し元の行番号を取得
        注意:
            !呼び出し元の上位行がすべて空の場合、常に1を返してしまうbugありTODO:修正!
        
        結果:
            呼び出し元の行
        """
        ...
    @staticmethod
    def get_primes(range: tuple[int, int]) -> list[int]: ...

 ##### ./tmp/src/variable_handling.py #####

class VariableHandling:
    """
    designed math（数式処理）モジュールの変数をハンドリングするクラス
    """

    @staticmethod
    def create_variables_symbol(existed_variables: dict[str, variable_symbol], variables: list[str], variable_types: variable_types_optional = {}) -> dict[str, variable_symbol]: ...

 ##### ./tmp/src/vector.py #####

class Vector:
    """
    A vector class designed for the math processing module.
    """

    def __init__(self, proof: Proof, elements: list[term_instance]) -> None:
        """
        Initializes the Vector object.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        elements : List[term_instance]
            A list of elements representing the vector.
        """
        ...
    @property
    def variables(self) -> set[str]:
        """
        Returns the set of variables in the vector.
        
        Returns
        -------
        set[str]
            A set of variable names.
        """
        ...
    @property
    def latex(self) -> str:
        """
        Returns the LaTeX representation of the vector.
        
        Returns
        -------
        str
            The LaTeX string of the vector.
        """
        ...
    def append(self, element: term_instance) -> Vector:
        """
        Appends an element to the vector.
        
        Parameters
        ----------
        element : term_instance
            The element to append.
        
        Returns
        -------
        Vector
            The updated vector.
        """
        ...
    def display(self) -> None:
        """
        Displays the vector using IPython Markdown.
        """
        ...
    def __add__(self, other: Vector) -> Vector:
        """
        Adds two vectors.
        
        Parameters
        ----------
        other : Vector
            The vector to add.
        
        Returns
        -------
        Vector
            The result of the addition.
        """
        ...
    def __eq__(self, other: Vector) -> bool:
        """
        Checks if two vectors are equal.
        
        Parameters
        ----------
        other : Vector
            The vector to compare.
        
        Returns
        -------
        bool
            True if the vectors are equal, False otherwise.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Formats the vector according to the specified format.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string representation of the vector.
        """
        ...
    def __getitem__(self, index: int) -> term_instance:
        """
        Returns the element at the specified index.
        
        Parameters
        ----------
        index : int
            The index of the element to retrieve.
        
        Returns
        -------
        term_instance
            The element at the specified index.
        """
        ...
    def __iter__(self) -> Generator[term_instance, None, None]:
        """
        Returns a generator for iterating over the vector elements.
        
        Returns
        -------
        Generator[term_instance, None, None]
            A generator for the vector elements.
        """
        ...
    def __len__(self) -> int:
        """
        Returns the number of elements in the vector.
        
        Returns
        -------
        int
            The number of elements.
        """
        ...
    def __neg__(self) -> Vector:
        """
        Negates the vector.
        
        Returns
        -------
        Vector
            The negated vector.
        """
        ...
    def __sub__(self, other: Vector) -> Vector:
        """
        Subtracts one vector from another.
        
        Parameters
        ----------
        other : Vector
            The vector to subtract.
        
        Returns
        -------
        Vector
            The result of the subtraction.
        """
        ...

class FormulaVector(Vector):
    """
    Formula vector class
    """

    def __init__(self, proof: Proof, elements: list[Formula]) -> None:
        """
        Initializes the FormulaVector object.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        elements : List[Formula]
            A list of formula elements representing the vector.
        """
        ...
    def append(self, element: Formula) -> FormulaVector:
        """
        Appends a formula element to the vector.
        
        Parameters
        ----------
        element : Formula
            The formula element to append.
        
        Returns
        -------
        FormulaVector
            The updated formula vector.
        """
        ...
    def __getitem__(self, index: int) -> Formula:
        """
        Returns the formula element at the specified index.
        
        Parameters
        ----------
        index : int
            The index of the formula element to retrieve.
        
        Returns
        -------
        Formula
            The formula element at the specified index.
        """
        ...
    def __iter__(self) -> Generator[term_instance, None, None]:
        """
        Returns a generator for iterating over the formula vector elements.
        
        Returns
        -------
        Generator[term_instance, None, None]
            A generator for the formula vector elements.
        """
        ...

class IntegerPair(Vector):
    """
    Integer pair class
    """

    def __init__(self, proof: Proof, pair: integer_pair_input, sum: integer_candidate_input | None = None, product: integer_candidate_input | None = None) -> None:
        """
        Initializes the IntegerPair object.
        
        Parameters
        ----------
        proof : Proof
            The proof object.
        pair : integer_pair_input
            A pair of integers.
        sum : Union[integer_candidate_input, None], optional
            The sum of the pair, by default None.
        product : Union[integer_candidate_input, None], optional
            The product of the pair, by default None.
        """
        ...
    @property
    def elements(self) -> integer_pair:
        """
        Returns the pair of integers.
        
        Returns
        -------
        integer_pair
            The pair of integers.
        """
        ...
    @property
    def product(self) -> integer_candidate:
        """
        Returns the product of the pair.
        
        Returns
        -------
        integer_candidate
            The product of the pair.
        """
        ...
    @property
    def sum(self) -> integer_candidate:
        """
        Returns the sum of the pair.
        
        Returns
        -------
        integer_candidate
            The sum of the pair.
        """
        ...
    def __getitem__(self, index: int) -> Formula | Integer:
        """
        Returns the element at the specified index.
        
        Parameters
        ----------
        index : int
            The index of the element to retrieve.
        
        Returns
        -------
        Union[Formula, Integer]
            The element at the specified index.
        
        """
        ...

class NaturalPair(IntegerPair):
    """
    Natural number pair class
    """

    def __init__(self, proof: Proof, pair: integer_pair_input, sum: integer_candidate_input | None = None, product: integer_candidate_input | None = None, gcd: integer_candidate_input | None = None, lcm: integer_candidate_input | None = None, relational_prime_pairs: list[tuple[integer_candidate_input, integer_candidate_input]] = []) -> None:
        """
        Initializes the NaturalPair object.
        Parameters
        ----------
        proof : Proof
            The proof object.
        pair : integer_pair_input
            A pair of integers.
        sum : Union[integer_candidate_input, None], optional
            The sum of the pair, by default None.
        product : Union[integer_candidate_input, None], optional
            The product of the pair, by default None.
        gcd : Union[integer_candidate_input, None], optional
            The greatest common divisor of the pair, by default None.
        lcm : Union[integer_candidate_input, None], optional
            The least common multiple of the pair, by default None.
        relational_prime_pairs : List[Tuple[integer_candidate_input, integer_candidate_input]], optional
            A list of relational prime pairs, by default [].
        """
        ...
    @property
    def gcd(self) -> NaturalPair | integer_candidate:
        """
        Returns the greatest common divisor of the pair.
        
        Returns
        -------
        Union[NaturalPair, integer_candidate]
            The greatest common divisor.
        """
        ...
    @property
    def gcd_history(self) -> Section:
        """
        Returns the history of the greatest common divisor calculation.
        
        Returns
        -------
        Section
            The history of the gcd calculation.
        """
        ...
    @property
    def lcm(self) -> integer_candidate | None:
        """
        Returns the least common multiple of the pair.
        
        Returns
        -------
        Union[integer_candidate, None]
            The least common multiple.
        """
        ...
    @property
    def product_relation_equation(self) -> Equation:
        """
        Returns the equation representing the relationship between the product, gcd, and lcm.
        
        Returns
        -------
        Equation
            The product relation equation.
        """
        ...
    @property
    def summation_relation_equation(self) -> Equation | None:
        """
        Returns the equation representing the relationship between the sum and other properties of the pair.
        
        Returns
        -------
        Union[Equation, None]
            The summation relation equation.
        """
        ...
    def display_gcd_history(self) -> NaturalPair:
        """
        Displays the history of the gcd calculation.
        
        Returns
        -------
        NaturalPair
            The NaturalPair object.
        """
        ...
    @overload
    def identify_from_condition(self, sum: int, lcm: None, gcd: int, section_title: str = '同定する_条件から', section_id: str = 'identify_from_condition') -> VectorSolutions:
        """
        Identifies integer pairs from the given conditions.
        
        Parameters
        ----------
        sum : int
            The sum of the integer pair.
        lcm : Union[int, None], optional
            The least common multiple, by default None.
        gcd : Union[int, None], optional
            The greatest common divisor, by default None.
        section_title : str, optional
            The title of the section, by default “Identify from Conditions".
        section_id : str, optional
            The ID of the section, by default “identify_from_condition".
        Returns
        -------
        VectorSolutions
            The vector solutions satisfying the given conditions.
        """
        ...
    @overload
    def identify_from_condition(self, sum: int, lcm: int, gcd: None = None, section_title: str = '同定する_条件から', section_id: str = 'identify_from_condition') -> VectorSolutions: ...

 ##### ./tmp/src/vector_solutions.py #####

class VectorSolutions:
    """
    A class representing vector equations solved for each variable.
    """

    def __init__(self, proof: Proof, equations: list[VectorEquation] | list[Solutions]) -> None:
        """
        Initializes the VectorSolutions object.
        
        Parameters
        ----------
        proof : Proof
            An object representing the proof.
        equations : Union[List[VectorEquation], List[Solutions]]
            A list of vector equations or solutions.
        """
        ...
    @property
    def equations(self) -> list[VectorEquation]:
        """
        Returns the list of vector equations.
        
        Returns
        -------
        List[VectorEquation]
            List of vector equations.
        """
        ...
    def add(self, vector_equations: list[VectorEquation] | VectorSolutions) -> VectorSolutions:
        """
        Adds vector equations to the current set of equations.
        
        Parameters
        ----------
        vector_equations : Union[List[VectorEquation], VectorSolutions]
            Vector equations or another VectorSolutions object to add.
        
        Returns
        -------
        VectorSolutions
            The updated VectorSolutions object.
        """
        ...
    def append(self, vector_equation: VectorEquation) -> VectorSolutions:
        """
        Appends a single vector equation to the current set of equations.
        
        Parameters
        ----------
        vector_equation : VectorEquation
            The vector equation to append.
        
        Returns
        -------
        VectorSolutions
            The updated VectorSolutions object.
        """
        ...
    def __iter__(self) -> Generator[VectorEquation, None, None]:
        """
        Returns a generator for iterating over the vector equations.
        
        Returns
        -------
        Generator[VectorEquation, None, None]
            A generator for the vector equations.
        """
        ...
    def __format__(self, __format_spec: str) -> str:
        """
        Formats the vector equations as a string according to the specified format.
        
        Parameters
        ----------
        __format_spec : str
            The format specification.
        
        Returns
        -------
        str
            The formatted string representation of the vector equations.
        """
        ...
    def __getitem__(self, index: int) -> VectorEquation:
        """
        Returns the vector equation at the specified index.
        
        Parameters
        ----------
        index : int
            The index of the vector equation to retrieve.
        
        Returns
        -------
        VectorEquation
            The vector equation at the specified index.
        """
        ...

 ##### ./tmp/src/ven_diagram.py #####

class VenDiagram:
    """
    Class representing a Venn diagram.
    """

    def __init__(self, data: list[vennData]) -> None:
        """
        Constructor
        
        Parameters
        ----------
        data : List[vennData]
            List of data for the Venn diagram.
        """
        ...
    def display(self) -> VenDiagram:
        """
        Display the Venn diagram.
        
        Returns
        -------
        VenDiagram
            Instance of the Venn diagram.
        """
        ...

 ##### ./tmp/src/ven_diagram_reservation.py #####

class VenDiagramReservation:
    """
    Class for reserving the display of Venn diagrams.
    Venn diagrams are rendered at the section where the instance is defined,
    and to avoid display disorder, this class delays the display.
    """

    def __init__(self, data: list[vennData]) -> None:
        """
        Initializes the VenDiagramReservation with Venn diagram data.
        
        Parameters
        ----------
        data : List[vennData]
            List of Venn diagram data
        """
        ...
    def display(self) -> VenDiagramReservation:
        """
        Displays the Venn diagram.
        
        Returns
        -------
        VenDiagramReservation
            Returns the instance itself
        """
        ...

 ##### ./tmp/src/define_type.py #####

SymbolCondition = Equation | Inequation | Unequation | ComplexCondition | SymbolicBool
Term = Formula | Float | Integer | Fraction

class subtract_prime_result(TypedDict):


    term: Formula
    signInteger: Literal[1, -1]

class Modee(TypedDict):


    residual: int
    power: int
markdown_str = str
integer_candidate = Integer | Formula
integer_candidate_input = int | integer_candidate
integer_pair_input = tuple[integer_candidate_input, integer_candidate_input]
integer_pair = tuple[integer_candidate, integer_candidate]
condition_symbol = Literal["True", "False"]
#

equation_symbol_ = Literal["="]

inequality_relation = Literal["<", "<=", ">", ">="]
inequation_symbol = Literal["<", "<=", ">", ">="]
term_type = type[Integer] | type[Float] | type[Fraction] | type[Formula]
table_data = dict[str, list[str | int | float]]
unequation_symbol = Literal["!="]

plotRange_ = tuple[tuple[int | float, int | float], tuple[int | float, int | float]]
symbol_relation_type = Literal[
    operator_symbol,
    number_symbol,
    condition_symbol,
    equation_symbol_,
    inequation_symbol,
    unequation_symbol,
]
symbol_type = Literal[symbol_relation_type, "symbol", condition_symbol]
type_from_term_inequation = type[SymbolicBool] | type[Inequation] | type[Inequation_v1] | type[Inequation_v2] | type[Equation] | type[Unequation] | type[ComplexCondition] | type[ComplexCondition_v1] | type[ComplexCondition_v2]

single_condition = Equation | Unequation | Inequation | Inequation_v1 | Inequation_v2 | SymbolicBool
symbol_range = Equation | Unequation | Inequation | Inequation_v1 | Inequation_v2 | ComplexCondition | ComplexCondition_v1 | ComplexCondition_v2
symbol_condition = symbol_range | SymbolicBool

class squared_result(TypedDict):


    square: Formula
    correction_term: Formula

class add_and_subtract_products_equation(TypedDict):


    left_plus_term: Formula
    left_minus_term: Formula
    right_constant_term: Integer | Fraction

class euclidean_output_each_process(TypedDict):


    result: NaturalPair
    explain: Section

class euclidean_output(TypedDict):


    result: NaturalPair | integer_candidate
    explain: Section

class variable_type_optional(TypedDict, total=False):


    commutative: Literal[True]
    complex: Literal[True]
    composite: Literal[True]
    even: Literal[True]
    extended_negative: Literal[True]
    extended_nonnegative: Literal[True]
    extended_nonpositive: Literal[True]
    extended_nonzero: Literal[True]
    extended_positive: Literal[True]
    extended_real: Literal[True]
    finite: Literal[True]
    imaginary: Literal[True]
    infinite: Literal[True]
    integer: Literal[True]
    irrational: Literal[True]
    negative: Literal[True]
    noninteger: Literal[True]
    nonnegative: Literal[True]
    nonpositive: Literal[True]
    nonzero: Literal[True]
    odd: Literal[True]
    positive: Literal[True]
    prime: Literal[True]
    rational: Literal[True]
    real: Literal[True]
    zero: Literal[True]





# Dependent type
variable_types_optional = dict[str, variable_type_optional]
explain = Section | RelationContent | str | MarkdownContents | Table | FigureReservation | VenDiagramReservation

class common_initialize_result(TypedDict):


    proof: Proof
    ast: astElement
    variables: set[str]

class equation_symbol(TypedDict):


    formula_left: variable_symbol
    formula_right: variable_symbol

class checked_variable(TypedDict):


    existed_variables: variables
    added_variables: set[str]

class condition(TypedDict):


    times: int
    mod: list[int]
term_instance = float | int | Integer | Float | Fraction | Formula
conditions_float = dict[str, float]
conditions_int = dict[str, int]
conditions_str = dict[str, str]
conditions_term = dict[str, Term]
conditions_fraction = dict[str, NativeFraction]
conditions_native = conditions_float | conditions_int | conditions_str
term_ = Term | float | int | NativeFraction
term = Term | str | float | int | NativeFraction



class Position_only_x(TypedDict, total=True):


    x: int | float | str

class Position_only_y(TypedDict, total=True):


    y: int | float | str

class Position_only(Position_only_x, Position_only_y):

 ...

class Annotation(TypedDict, total=False):


    annotation: str

class Position(Position_only, Annotation):

 ...
class Position_x(Position_only_x, Annotation):

 ...

class Positions_only_x(TypedDict, total=True):


    x: list[int] | list[float] | list[str]

class Positions_only_y(TypedDict, total=True):


    y: list[int | float | str]

class Positions_only(Positions_only_x, Positions_only_y):

 ...

class Annotations(TypedDict, total=False):


    annotation: list[str]

class Positions_list(Positions_only, Annotations):

 ...
class Positions_list_x(Positions_only_x, Annotations):

 ...

class result_of_factorized_and_split(TypedDict):


    inequations: tuple[tuple[Inequation, Inequation], tuple[Inequation, Inequation]] | None
    relation_index: Literal[0, 1, 2, 3]



#


#

relation_content = symbol_condition | Term | MathConditional | Solutions | VectorEquation | VectorSolutions | Vector

express_term = tuple[term, term]
